@@ -27,8 +27,8 @@ import keyring
 from flask import current_app, render_template, url_for, make_response, \
     flash, Response, request, after_this_request, redirect, session
 from flask_babel import gettext
-from flask_gravatar import Gravatar
-from flask_login import current_user, login_required
+from libgravatar import Gravatar
+from flask_security import current_user
 from flask_login.utils import login_url
 from flask_security.changeable import send_password_changed_notice
 from flask_security.decorators import anonymous_user_required
@@ -64,12 +64,8 @@ from pgadmin.utils.constants import MIMETYPE_APP_JS, PGADMIN_NODE,\
 from pgadmin.authenticate import AuthSourceManager
 from pgadmin.utils.exception import CryptKeyMissing
 
-try:
-    from flask_security.views import default_render_json
-except ImportError as e:
-    # Support Flask-Security-Too == 3.2
-    if sys.version_info < (3, 8):
-        from flask_security.views import _render_json as default_render_json
+from pgadmin.user_login_check import pga_login_required
+from flask_security.views import default_render_json
 
 MODULE_NAME = 'browser'
 BROWSER_STATIC = 'browser.static'
@@ -360,24 +356,26 @@ def _get_supported_browser():
     return browser_name, browser_known, version
 
 
+@blueprint.add_app_template_filter
+def gravatar(username):
+    """
+    This function adds a template filter which
+    returns gravatar image for user.
+    :return: gravatar image
+    """
+    g = Gravatar(username)
+    return g.get_image(
+        size=100,
+        rating='g',
+        default='retro'
+    )
+
+
 @blueprint.route("/")
 @pgCSRFProtect.exempt
-@login_required
-@mfa_required
+@pga_login_required
 def index():
     """Render and process the main browser window."""
-    # Register Gravatar module with the app only if required
-    if config.SHOW_GRAVATAR_IMAGE:
-        Gravatar(
-            current_app,
-            size=100,
-            rating='g',
-            default='retro',
-            force_default=False,
-            force_lower=True,
-            use_ssl=True,
-            base_url=None
-        )
 
     # Check the browser is a supported version
     # NOTE: If the checks here are updated, make sure the supported versions
@@ -468,13 +466,12 @@ def get_shared_storage_list():
 
 @blueprint.route("/js/utils.js")
 @pgCSRFProtect.exempt
-@login_required
+@pga_login_required
 def utils():
     layout = get_setting('Browser/Layout', default='')
     snippets = []
 
     prefs = Preferences.module('paths')
-
     pg_help_path_pref = prefs.preference('pg_help_path')
     pg_help_path = pg_help_path_pref.get()
 
@@ -493,6 +490,11 @@ def utils():
     brace_matching_pref = prefs.preference('brace_matching')
     brace_matching = brace_matching_pref.get()
 
+    highlight_selection_matches_pref = prefs.preference(
+        'highlight_selection_matches'
+    )
+    highlight_selection_matches = highlight_selection_matches_pref.get()
+
     insert_pair_brackets_perf = prefs.preference('insert_pair_brackets')
     insert_pair_brackets = insert_pair_brackets_perf.get()
 
@@ -545,6 +547,7 @@ def utils():
             editor_use_spaces=editor_use_spaces,
             editor_wrap_code=editor_wrap_code,
             editor_brace_matching=brace_matching,
+            editor_highlight_selection_matches=highlight_selection_matches,
             editor_insert_pair_brackets=insert_pair_brackets,
             editor_indent_with_tabs=editor_indent_with_tabs,
             app_name=config.APP_NAME,
@@ -585,7 +588,7 @@ def exposed_urls():
 
 @blueprint.route("/js/error.js")
 @pgCSRFProtect.exempt
-@login_required
+@pga_login_required
 def error_js():
     return make_response(
         render_template('browser/js/error.js', _=gettext),
@@ -602,7 +605,7 @@ def messages_js():
 
 @blueprint.route("/browser.css")
 @pgCSRFProtect.exempt
-@login_required
+@pga_login_required
 def browser_css():
     """Render and return CSS snippets from the nodes and modules."""
     snippets = []
@@ -617,7 +620,7 @@ def browser_css():
 
 
 @blueprint.route("/nodes/", endpoint="nodes")
-@login_required
+@pga_login_required
 def get_nodes():
     """Build a list of treeview nodes from the child nodes."""
     nodes = []
@@ -924,7 +927,7 @@ if hasattr(config, 'SECURITY_CHANGEABLE') and config.SECURITY_CHANGEABLE:
     @blueprint.route("/change_password", endpoint="change_password",
                      methods=['GET', 'POST'])
     @pgCSRFProtect.exempt
-    @login_required
+    @pga_login_required
     def change_password():
         """View function which handles a change password request."""
 
@@ -1065,7 +1068,7 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
 
         for errors in form.errors.values():
             for error in errors:
-                flash(error, MessageType.WARNING)
+                flash(str(error), MessageType.WARNING)
 
         return _security.render_template(
             config_value('FORGOT_PASSWORD_TEMPLATE'),
@@ -1100,6 +1103,8 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
         form_class = _security.forms.get('reset_password_form').cls
         form = form_class(request.form) if request.form else form_class()
 
+        form.user = user
+
         if form.validate_on_submit():
             try:
                 update_password(user, form.password.data)
@@ -1127,7 +1132,7 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
                 has_error = True
 
             if not has_error:
-                after_this_request(view_commit)
+                view_commit()
                 auth_obj = AuthSourceManager(form, [INTERNAL])
                 session['_auth_source_manager_obj'] = auth_obj.as_dict()
 
@@ -1142,8 +1147,9 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
                 auth_obj = AuthSourceManager(form, [INTERNAL])
                 session['auth_source_manager'] = auth_obj.as_dict()
 
-                return redirect(get_url(_security.post_reset_view) or
-                                get_url(_security.post_login_view))
+                return redirect(
+                    current_app.config['SECURITY_POST_RESET_VIEW'] or
+                    current_app.config['SECURITY_POST_LOGIN_VIEW'])
 
         return _security.render_template(
             config_value('RESET_PASSWORD_TEMPLATE'),
