@@ -2,7 +2,7 @@
 #
 # pgAdmin 4 - PostgreSQL Tools
 #
-# Copyright (C) 2013 - 2023, The pgAdmin Development Team
+# Copyright (C) 2013 - 2024, The pgAdmin Development Team
 # This software is released under the PostgreSQL Licence
 #
 ##########################################################################
@@ -27,7 +27,7 @@ class FtsDictionaryAddTestCase(BaseTestGenerator):
 
     scenarios = [
         # Fetching default URL for FTS dictionary node.
-        ('Fetch FTS dictionary Node URL', dict(
+        ('Add FTS dictionary', dict(
             url='/browser/fts_dictionary/obj/'))
     ]
 
