@@ -11,12 +11,12 @@ ALTER SEQUENCE IF EXISTS {{ conn|qtIdent(o_data.schema, data.name) }}
     OWNER TO {{ conn|qtIdent(data.seqowner) }};
 
 {% endif %}
-{% if (data.owned_table == None) and (data.owned_column == None) %}
+{% if (data.owned_table == None and data.owned_column == None) or (data.owned_table == '' and data.owned_column == '') %}
 ALTER SEQUENCE IF EXISTS {{ conn|qtIdent(o_data.schema, data.name) }}
     OWNED BY NONE;
 {% elif (data.owned_table is defined or data.owned_column is defined) and (data.owned_table != o_data.owned_table or data.owned_column != o_data.owned_column) %}
 ALTER SEQUENCE IF EXISTS {{ conn|qtIdent(o_data.schema, data.name) }}
-    OWNED BY {% if data.owned_table is defined %}{{ conn|qtIdent(data.owned_table) }}{% else %}{{ conn|qtIdent(o_data.owned_table) }}{% endif %}.{% if data.owned_column is defined %}{{ conn|qtIdent(data.owned_column) }}{% else %}{{ conn|qtIdent(o_data.owned_column) }}{% endif %};
+    OWNED BY {{ conn|qtIdent(o_data.schema) }}.{% if data.owned_table is defined %}{{ conn|qtIdent(data.owned_table) }}{% else %}{{ conn|qtIdent(o_data.owned_table) }}{% endif %}.{% if data.owned_column is defined %}{{ conn|qtIdent(data.owned_column) }}{% else %}{{ conn|qtIdent(o_data.owned_column) }}{% endif %};
 {% endif %}
 {% if data.current_value is defined %}
 {% set seqname = conn|qtIdent(o_data.schema, data.name) %}
