@@ -1,4 +1,4 @@
-CREATE TABLE IF NOT EXISTS public."simple_table_with_pk$%{}[]()&*^!@""'`\/#"
+CREATE TABLE public."simple_table_with_pk$%{}[]()&*^!@""'`\/#"
 (
     "col1_$%{}[]()&*^!@\""'`\\/#" integer,
     "col2_$%{}[]()&*^!@\""'`\\/#" json NOT NULL,
@@ -8,7 +8,7 @@ WITH (
     OIDS = FALSE
 );
 
-ALTER TABLE public."simple_table_with_pk$%{}[]()&*^!@""'`\/#"
+ALTER TABLE IF EXISTS public."simple_table_with_pk$%{}[]()&*^!@""'`\/#"
     OWNER to enterprisedb;
 
 COMMENT ON TABLE public."simple_table_with_pk$%{}[]()&*^!@""'`\/#"
