@@ -7,13 +7,13 @@
 //
 //////////////////////////////////////////////////////////////
 import React, { useState, useEffect, useRef, useReducer, useMemo } from 'react';
+import { styled } from '@mui/material/styles';
 import gettext from 'sources/gettext';
 import PropTypes from 'prop-types';
-import { makeStyles } from '@material-ui/core/styles';
 import url_for from 'sources/url_for';
 import {getGCD, getEpoch} from 'sources/utils';
 import ChartContainer from '../components/ChartContainer';
-import { Grid } from '@material-ui/core';
+import { Grid } from '@mui/material';
 import { DATA_POINT_SIZE } from 'sources/chartjs';
 import StreamingChart from '../../../../static/js/components/PgChart/StreamingChart';
 import {useInterval, usePrevious} from 'sources/custom_hooks';
@@ -21,38 +21,12 @@ import axios from 'axios';
 import { BarChart, PieChart } from '../../../../static/js/chartjs';
 import { getStatsUrl, transformData, X_AXIS_LENGTH } from './utility.js';
 import { toPrettySize } from '../../../../static/js/utils';
-import clsx from 'clsx';
-import { commonTableStyles } from '../../../../static/js/Theme';
+import Table from '../../../../static/js/components/Table';
+import SectionContainer from '../components/SectionContainer.jsx';
 
-const useStyles = makeStyles((theme) => ({
-  container: {
-    height: 'auto',
-    padding: '8px',
-    marginBottom: '6px',
-  },
-  driveContainer: {
-    width: '100%',
-  },
-  diskInfoContainer: {
-    height: 'auto',
-    padding: '8px 8px 0px 8px',
-    marginBottom: '0px',
-  },
-  diskInfoSummary: {
-    height: 'auto',
-    padding: '0px 0px 4px 0px',
-    marginBottom: '0px',
-  },
-  diskInfoCharts: {
-    height: 'auto',
-    padding: '0px 0px 2px 0px',
-    marginBottom: '0px',
-  },
-  containerHeaderText: {
-    fontWeight: 'bold',
-    padding: '4px 8px',
-  },
-  tableContainer: {
+
+const Root = styled('div')(({theme}) => ({
+  '& .Storage-tableContainer': {
     background: theme.otherVars.tableBg,
     padding: '0px',
     border: '1px solid '+theme.otherVars.borderColor,
@@ -61,24 +35,15 @@ const useStyles = makeStyles((theme) => ({
     overflow: 'auto',
     width: '100%',
     margin: '4px 4px 4px 4px',
-  },
-  tableWhiteSpace: {
-    '& td, & th': {
-      whiteSpace: 'break-spaces !important',
+    '& .Storage-containerHeaderText': {
+      fontWeight: 'bold',
+      padding: '4px 8px',
+    },
+    '& .Storage-tableWhiteSpace': {
+      '& td, & th': {
+        whiteSpace: 'break-spaces !important',
+      },
     },
-  },
-  driveContainerHeader: {
-    height: 'auto',
-    padding: '5px 0px 0px 0px',
-    background: theme.otherVars.tableBg,
-    marginBottom: '5px',
-    borderRadius: '4px 4px 0px 0px',
-  },
-  driveContainerBody: {
-    height: 'auto',
-    padding: '0px',
-    background: theme.otherVars.tableBg,
-    borderRadius: '0px 0px 4px 4px',
   },
 }));
 
@@ -134,29 +99,28 @@ const chartsDefault = {
 
 
 const DiskStatsTable = (props) => {
-  const tableClasses = commonTableStyles();
-  const classes = useStyles();
+
   const tableHeader = props.tableHeader;
   const data = props.data;
   return (
-    <table className={clsx(tableClasses.table, classes.tableWhiteSpace)}>
+    <Table classNameRoot='Storage-tableWhiteSpace'>
       <thead>
         <tr>
-          {tableHeader.map((item, index) => (
-            <th key={index}>{item.Header}</th>
+          {tableHeader.map((item) => (
+            <th key={item.header}>{item.header}</th>
           ))}
         </tr>
       </thead>
       <tbody>
-        {data.map((item, index) => (
-          <tr key={index}>
+        {data.map((item) => (
+          <tr key={item.file_system_type + item.mount_point}>
             {tableHeader.map((header, id) => (
-              <td key={header.accessor+'-'+id}>{item[header.accessor]}</td>
+              <td key={header.accessorKey+'-'+id}>{item[header.accessorKey]}</td>
             ))}
           </tr>
         ))}
       </tbody>
-    </table>
+    </Table>
   );
 };
 
@@ -172,52 +136,50 @@ export default function Storage({preferences, sid, did, pageVisible, enablePoll=
   const [diskStats, setDiskStats] = useState([]);
   const [ioInfo, ioInfoReduce] = useReducer(ioStatsReducer, chartsDefault['io_stats']);
 
-  const [, setCounterData] = useState({});
-
   const [pollDelay, setPollDelay] = useState(5000);
   const [errorMsg, setErrorMsg] = useState(null);
   const [chartDrawnOnce, setChartDrawnOnce] = useState(false);
 
   const tableHeader = [
     {
-      Header: gettext('File system'),
-      accessor: 'file_system',
+      header: gettext('File system'),
+      accessorKey: 'file_system',
     },
     {
-      Header: gettext('File system type'),
-      accessor: 'file_system_type',
+      header: gettext('File system type'),
+      accessorKey: 'file_system_type',
     },
     {
-      Header: gettext('Mount point'),
-      accessor: 'mount_point',
+      header: gettext('Mount point'),
+      accessorKey: 'mount_point',
     },
     {
-      Header: gettext('Drive letter'),
-      accessor: 'drive_letter',
+      header: gettext('Drive letter'),
+      accessorKey: 'drive_letter',
     },
     {
-      Header: gettext('Total space'),
-      accessor: 'total_space',
+      header: gettext('Total space'),
+      accessorKey: 'total_space',
     },
     {
-      Header: gettext('Used space'),
-      accessor: 'used_space',
+      header: gettext('Used space'),
+      accessorKey: 'used_space',
     },
     {
-      Header: gettext('Free space'),
-      accessor: 'free_space',
+      header: gettext('Free space'),
+      accessorKey: 'free_space',
     },
     {
-      Header: gettext('Total inodes'),
-      accessor: 'total_inodes',
+      header: gettext('Total inodes'),
+      accessorKey: 'total_inodes',
     },
     {
-      Header: gettext('Used inodes'),
-      accessor: 'used_inodes',
+      header: gettext('Used inodes'),
+      accessorKey: 'used_inodes',
     },
     {
-      Header: gettext('Free inodes'),
-      accessor: 'free_inodes',
+      header: gettext('Free inodes'),
+      accessorKey: 'free_inodes',
     },
   ];
 
@@ -351,18 +313,10 @@ export default function Storage({preferences, sid, did, pageVisible, enablePoll=
           }
           ioInfoReduce({incoming: new_io_stats});
         }
-
-        setCounterData((prevCounterData)=>{
-          return {
-            ...prevCounterData,
-            ...data,
-          };
-        });
       })
       .catch((error)=>{
         if(!errorMsg) {
           ioInfoReduce({reset:chartsDefault['io_stats']});
-          setCounterData({});
           if(error.response) {
             if (error.response.status === 428) {
               setErrorMsg(gettext('Please connect to the selected server to view the graph.'));
@@ -380,7 +334,7 @@ export default function Storage({preferences, sid, did, pageVisible, enablePoll=
   }, enablePoll ? pollDelay : -1);
 
   return (
-    <>
+    (<Root>
       <div data-testid='graph-poll-delay' style={{display: 'none'}}>{pollDelay}</div>
       {chartDrawnOnce &&
         <StorageWrapper
@@ -395,7 +349,7 @@ export default function Storage({preferences, sid, did, pageVisible, enablePoll=
           isTest={false}
         />
       }
-    </>
+    </Root>)
   );
 }
 
@@ -409,7 +363,7 @@ Storage.propTypes = {
 };
 
 export function StorageWrapper(props) {
-  const classes = useStyles();
+
   const options = useMemo(()=>({
     showDataPoints: props.showDataPoints,
     showTooltip: props.showTooltip,
@@ -436,115 +390,131 @@ export function StorageWrapper(props) {
     },
   };
 
+  function getLabel(item, index) {
+    if (item.mount_point !== '')
+      return item.mount_point;
+
+    return item.drive_letter !== '' ? item.drive_letter : 'disk' + index;
+  }
+
+  function getChartContainerTitle(type) {
+    if (type.endsWith('_bytes_rw'))
+      return gettext('Data transfer');
+    if (type.endsWith('_total_rw'))
+      return gettext('I/O operations count');
+    if (type.endsWith('_time_rw'))
+      return gettext('Time spent in I/O operations');
+
+    return '';
+  }
+
+  function getValue(type, v) {
+    if (type.endsWith('_time_rw'))
+      return toPrettySize(v, 'ms');
+    if (type.endsWith('_total_rw'))
+      return toPrettySize(v, '');
+
+    return toPrettySize(v);
+  }
+
   return (
-    <>
-      <Grid container spacing={1} className={classes.diskInfoContainer}>
-        <Grid container spacing={1} className={classes.diskInfoSummary}>
-          <div className={classes.tableContainer}>
-            <div className={classes.containerHeaderText}>{gettext('Disk information')}</div>
-            <DiskStatsTable tableHeader={props.tableHeader} data={props.diskStats} />
-          </div>
-        </Grid>
-        <Grid container spacing={1} className={classes.diskInfoCharts}>
-          <Grid item md={6} sm={12}>
-            <ChartContainer
-              id='t-space-graph'
-              title={''}
-              datasets={props.diskStats.map((item, index) => ({
-                borderColor: colors[(index + 2) % colors.length],
-                label: item.mount_point !== '' ? item.mount_point : item.drive_letter !== '' ? item.drive_letter : 'disk' + index,
-              }))}
-              errorMsg={props.errorMsg}
-              isTest={props.isTest}>
-              <PieChart data={{
-                labels: props.diskStats.map((item, index) => item.mount_point!=''?item.mount_point:item.drive_letter!=''?item.drive_letter:'disk'+index),
-                datasets: [
-                  {
-                    data: props.diskStats.map((item) => item.total_space_actual?item.total_space_actual:0),
-                    backgroundColor: props.diskStats.map((item, index) => colors[(index + 2) % colors.length]),
-                  },
-                ],
-              }}
-              options={{
-                animation: false,
-                ...chartJsExtraOptions,
-              }}
-              />
-            </ChartContainer>
-          </Grid>
-          <Grid item md={6} sm={12}>
-            <ChartContainer id='ua-space-graph' title={''} datasets={[{borderColor: '#FF6384', label: 'Used space'}, {borderColor: '#36a2eb', label: 'Available space'}]}  errorMsg={props.errorMsg} isTest={props.isTest}>
-              <BarChart data={{
-                labels: props.diskStats.map((item, index) => item.mount_point!=''?item.mount_point:item.drive_letter!=''?item.drive_letter:'disk'+index),
-                datasets: [
-                  {
-                    label: 'Used space',
-                    data: props.diskStats.map((item) => item.used_space_actual?item.used_space_actual:0),
-                    backgroundColor: '#FF6384',
-                    borderColor: '#FF6384',
-                    borderWidth: 1,
-                  },
-                  {
-                    label: 'Available space',
-                    data: props.diskStats.map((item) => item.free_space_actual?item.free_space_actual:0),
-                    backgroundColor: '#36a2eb',
-                    borderColor: '#36a2eb',
-                    borderWidth: 1,
-                  },
-                ],
-              }}
-              options={
+    <Root>
+      <div className='Storage-tableContainer'>
+        <div className='Storage-containerHeaderText'>{gettext('Disk information')}</div>
+        <DiskStatsTable tableHeader={props.tableHeader} data={props.diskStats} />
+      </div>
+      <Grid container spacing={0.5} sx={{marginBottom: '4px'}}>
+        <Grid item md={6} sm={12}>
+          <ChartContainer
+            id='t-space-graph'
+            title={''}
+            datasets={props.diskStats.map((item, index) => ({
+              borderColor: colors[(index + 2) % colors.length],
+              label: getLabel(item, index),
+            }))}
+            errorMsg={props.errorMsg}
+            isTest={props.isTest}>
+            <PieChart data={{
+              labels: props.diskStats.map((item, index) => getLabel(item, index)),
+              datasets: [
                 {
-                  scales: {
-                    x: {
+                  data: props.diskStats.map((item) => item.total_space_actual?item.total_space_actual:0),
+                  backgroundColor: props.diskStats.map((item, index) => colors[(index + 2) % colors.length]),
+                },
+              ],
+            }}
+            options={{
+              animation: false,
+              ...chartJsExtraOptions,
+            }}
+            />
+          </ChartContainer>
+        </Grid>
+        <Grid item md={6} sm={12}>
+          <ChartContainer id='ua-space-graph' title={''} datasets={[{borderColor: '#FF6384', label: 'Used space'}, {borderColor: '#36a2eb', label: 'Available space'}]}  errorMsg={props.errorMsg} isTest={props.isTest}>
+            <BarChart data={{
+              labels: props.diskStats.map((item, index) => getLabel(item, index)),
+              datasets: [
+                {
+                  label: 'Used space',
+                  data: props.diskStats.map((item) => item.used_space_actual?item.used_space_actual:0),
+                  backgroundColor: '#FF6384',
+                  borderColor: '#FF6384',
+                  borderWidth: 1,
+                },
+                {
+                  label: 'Available space',
+                  data: props.diskStats.map((item) => item.free_space_actual?item.free_space_actual:0),
+                  backgroundColor: '#36a2eb',
+                  borderColor: '#36a2eb',
+                  borderWidth: 1,
+                },
+              ],
+            }}
+            options={
+              {
+                scales: {
+                  x: {
+                    display: true,
+                    stacked: true,
+                    ticks: {
                       display: true,
-                      stacked: true,
-                      ticks: {
-                        display: true,
-                      },
                     },
-                    y: {
-                      beginAtZero: true,
-                      stacked: true,
-                      ticks: {
-                        callback: function (value) {
-                          return toPrettySize(value);
-                        },
+                  },
+                  y: {
+                    beginAtZero: true,
+                    stacked: true,
+                    ticks: {
+                      callback: function (value) {
+                        return toPrettySize(value);
                       },
                     },
                   },
-                  ...chartJsExtraOptions,
-                }
+                },
+                ...chartJsExtraOptions,
               }
-              />
-            </ChartContainer>
-          </Grid>
+            }
+            />
+          </ChartContainer>
         </Grid>
       </Grid>
-      <Grid container spacing={1} className={classes.container}>
-        {Object.keys(props.ioInfo).map((drive, index) => (
-          <Grid key={`disk-${index}`} container spacing={1} className={classes.container}>
-            <div className={classes.driveContainer}>
-              <Grid container spacing={1} className={classes.driveContainerHeader}>
-                <div className={classes.containerHeaderText}>{gettext(drive)}</div>
+      {Object.keys(props.ioInfo).map((drive) => (
+        <SectionContainer key={drive} title={drive} style={{minHeight: 'unset', height: 'auto', marginBottom: '0.5px'}}>
+          <Grid container spacing={0.5} p={0.5}>
+            {Object.keys(props.ioInfo[drive]).map((type, innerKeyIndex) => (
+              <Grid key={`${type}-${innerKeyIndex}`} item md={4} sm={6}>
+                <ChartContainer id={`io-graph-${type}`} title={getChartContainerTitle(type)} datasets={transformData(props.ioInfo[drive][type], props.ioRefreshRate).datasets}  errorMsg={props.errorMsg} isTest={props.isTest}>
+                  <StreamingChart data={transformData(props.ioInfo[drive][type], props.ioRefreshRate)} dataPointSize={DATA_POINT_SIZE} xRange={X_AXIS_LENGTH} options={options}
+                    valueFormatter={(v)=>{
+                      return getValue(type, v);
+                    }} />
+                </ChartContainer>
               </Grid>
-              <Grid container spacing={1} className={classes.driveContainerBody}>
-                {Object.keys(props.ioInfo[drive]).map((type, innerKeyIndex) => (
-                  <Grid key={`${type}-${innerKeyIndex}`} item md={4} sm={6}>
-                    <ChartContainer id={`io-graph-${type}`} title={type.endsWith('_bytes_rw') ? gettext('Data transfer'): type.endsWith('_total_rw') ? gettext('I/O operations count'): type.endsWith('_time_rw') ? gettext('Time spent in I/O operations'):''} datasets={transformData(props.ioInfo[drive][type], props.ioRefreshRate).datasets}  errorMsg={props.errorMsg} isTest={props.isTest}>
-                      <StreamingChart data={transformData(props.ioInfo[drive][type], props.ioRefreshRate)} dataPointSize={DATA_POINT_SIZE} xRange={X_AXIS_LENGTH} options={options}
-                        valueFormatter={(v)=>{
-                          return type.endsWith('_time_rw') ? toPrettySize(v, 'ms') : type.endsWith('_total_rw') ? toPrettySize(v, ''): toPrettySize(v);
-                        }} />
-                    </ChartContainer>
-                  </Grid>
-                ))}
-              </Grid>
-            </div>
+            ))}
           </Grid>
-        ))}
-      </Grid>
-    </>
+        </SectionContainer>
+      ))}
+    </Root>
   );
 }
 
