@@ -13,7 +13,7 @@ import { isEmptyString } from 'sources/validators';
 import pgAdmin from 'sources/pgadmin';
 
 class AzureCredSchema extends BaseUISchema {
-  constructor(fieldOptions = {}, initValues = {}, eventBus) {
+  constructor(eventBus, fieldOptions = {}, initValues = {}) {
     super({
       oid: null,
       auth_type: 'interactive_browser_credential',
@@ -67,7 +67,7 @@ class AzureCredSchema extends BaseUISchema {
             value: 'azure_cli_credential',
           },
         ],
-        disabled: pgAdmin.server_mode == 'True' ? true : false,
+        disabled: pgAdmin.server_mode == 'True',
         helpMessage: gettext(
           'Azure CLI will use the currently logged in identity through the Azure CLI on the local machine. Interactive Browser will open a browser window to authenticate a user interactively.'
         ),
@@ -82,9 +82,7 @@ class AzureCredSchema extends BaseUISchema {
           'Enter the Azure tenant ID against which the user is authenticated.'
         ),
         disabled: (state) => {
-          return state.auth_type == 'interactive_browser_credential'
-            ? false
-            : true;
+          return state.auth_type !== 'interactive_browser_credential';
         },
         depChange: (state) => {
           if (state.auth_type == 'azure_cli_credential') {
@@ -124,7 +122,7 @@ class AzureCredSchema extends BaseUISchema {
                   }));
                 })
                 .catch((err)=>{
-                  reject(err);
+                  reject(err instanceof Error ? err : Error(gettext('Something went wrong')));
                 });
             }
           });
@@ -154,7 +152,7 @@ class AzureCredSchema extends BaseUISchema {
                   });
                 })
                 .catch((err)=>{
-                  reject(err);
+                  reject(err instanceof Error ? err : Error(gettext('Something went wrong')));
                 });
             }
           });
@@ -493,7 +491,7 @@ class AzureDatabaseSchema extends BaseUISchema {
         noEmpty: true,
         helpMessage: gettext(
           'The password must be 8-128 characters long and must contain characters from three of the following categories - English uppercase letters, English lowercase letters, numbers (0-9), and non-alphanumeric characters (!, $, #, %, etc.), and cannot contain all or part of the login name'
-        ),
+        ), controlProps: { autoComplete: 'new-password' }
       },
       {
         id: 'db_confirm_password',
@@ -719,7 +717,7 @@ class AzureClusterSchema extends BaseUISchema {
   }
 
   validate(data, setErr) {
-    if ( !isEmptyString(data.name) && (!/^[a-z0-9\-]*$/.test(data.name) || data.name.length < 3)) {
+    if ( !isEmptyString(data.name) && (!/^[a-z0-9-]*$/.test(data.name) || data.name.length < 3)) {
       setErr('name',gettext('Name must be more than 2 characters and must only contain lowercase letters, numbers, and hyphens'));
       return true;
     }
