@@ -18,15 +18,6 @@ import getApiInstance from '../../../../static/js/api_instance';
 import { CloudWizardEventsContext } from './CloudWizard';
 import {MESSAGE_TYPE } from '../../../../static/js/components/FormComponents';
 import gettext from 'sources/gettext';
-import { makeStyles } from '@material-ui/core/styles';
-
-const useStyles = makeStyles(() =>
-  ({
-    formClass: {
-      overflow: 'auto',
-    }
-  }),
-);
 
 
 export function GoogleCredentials(props) {
@@ -62,7 +53,7 @@ export function GoogleCredentials(props) {
           })
           .catch((error) => {
             _eventBus.fireEvent('SET_ERROR_MESSAGE_FOR_CLOUD_WIZARD',[MESSAGE_TYPE.ERROR, gettext(`Error while authentication: ${error}`)]);
-            reject(false);
+            reject(new Error(gettext(`Error while authentication: ${error}`)));
           });
         });
       },
@@ -96,7 +87,7 @@ export function GoogleCredentials(props) {
               })
               .catch((error)=>{
                 clearInterval(interval);
-                reject(error);
+                reject(error instanceof Error ? error : Error(gettext('Something went wrong')));
               });
             countdown = countdown - 1;
           }, 1000);
@@ -126,7 +117,6 @@ GoogleCredentials.propTypes = {
 // Google Instance
 export function GoogleInstanceDetails(props) {
   const [googleInstanceSchema, setGoogleInstanceSchema] = React.useState();
-  const classes = useStyles();
 
   React.useMemo(() => {
     const GoogleClusterSchemaObj = new GoogleClusterSchema({
@@ -186,7 +176,6 @@ export function GoogleInstanceDetails(props) {
     onDataChange={(isChanged, changedData) => {
       props.setGoogleInstanceData(changedData);
     }}
-    formClassName={classes.formClass}
   />;
 }
 GoogleInstanceDetails.propTypes = {
@@ -201,8 +190,7 @@ GoogleInstanceDetails.propTypes = {
 
 // Google Database Details
 export function GoogleDatabaseDetails(props) {
-  const [gooeleDBInstance, setGoogleDBInstance] = React.useState();
-  const classes = useStyles();
+  const [googleDBInstance, setGoogleDBInstance] = React.useState();
 
   React.useMemo(() => {
     const googleDBSchema = new GoogleDatabaseSchema({
@@ -220,13 +208,12 @@ export function GoogleDatabaseDetails(props) {
     formType={'dialog'}
     getInitData={() => { /*This is intentional (SonarQube)*/ }}
     viewHelperProps={{ mode: 'create' }}
-    schema={gooeleDBInstance}
+    schema={googleDBInstance}
     showFooter={false}
     isTabView={false}
     onDataChange={(isChanged, changedData) => {
       props.setGoogleDatabaseData(changedData);
     }}
-    formClassName={classes.formClass}
   />;
 }
 GoogleDatabaseDetails.propTypes = {
