@@ -1,4 +1,12 @@
-import { Box } from '@material-ui/core';
+/////////////////////////////////////////////////////////////
+//
+// pgAdmin 4 - PostgreSQL Tools
+//
+// Copyright (C) 2013 - 2024, The pgAdmin Development Team
+// This software is released under the PostgreSQL Licence
+//
+//////////////////////////////////////////////////////////////
+import { Box } from '@mui/material';
 import React, { useState } from 'react';
 import LoginImage from '../../img/login.svg?svgr';
 import { FormNote, InputText } from '../components/FormComponents';
@@ -68,39 +76,37 @@ AuthenticatorRegisterView.propTypes = {
 
 export default function MfaRegisterPage({actionUrl, mfaList, nextUrl, mfaView, ...props}) {
   return (
-    <>
-      <BasePage title={gettext('Authentication Registration')} pageImage={<LoginImage style={{height: '100%', width: '100%'}} />} {...props}>
-        <form style={{display:'flex', gap:'15px', flexDirection:'column', minHeight: 0}} action={actionUrl} method="POST">
-          {mfaView ? <>
-            {mfaView.auth_method == 'email' && <EmailRegisterView mfaView={mfaView} />}
-            {mfaView.auth_method == 'authenticator' && <AuthenticatorRegisterView mfaView={mfaView} />}
-            <Box display="flex" gridGap="15px">
-              <SecurityButton name="continue" value="Continue">{gettext('Continue')}</SecurityButton>
-              <DefaultButton type="submit" name="cancel" value="Cancel" style={{width: '100%'}}>{gettext('Cancel')}</DefaultButton>
-            </Box>
-          </>:<>
-            {mfaList?.map((m)=>{
-              return (
-                <Box display="flex" width="100%" key={m.label}>
-                  <div style={{
-                    width: '10%', mask: `url(${m.icon})`, maskRepeat: 'no-repeat',
-                    WebkitMask: `url(${m.icon})`, WebkitMaskRepeat: 'no-repeat',
-                    backgroundColor: '#fff'
-                  }}>
-                  </div>
-                  <div style={{width: '70%'}}>{m.label}</div>
-                  <div style={{width: '20%'}}>
-                    <SecurityButton name={m.id} value={m.registered ? 'DELETE' : 'SETUP'}>{m.registered ? gettext('Delete') : gettext('Setup')}</SecurityButton>
-                  </div>
-                </Box>
-              );
-            })}
-            {nextUrl != 'internal' && <SecurityButton value="Continue">{gettext('Continue')}</SecurityButton>}
-          </>}
-          <div><input type="hidden" name="next" value={nextUrl}/></div>
-        </form>
-      </BasePage>
-    </>
+    <BasePage title={gettext('Authentication Registration')} pageImage={<LoginImage style={{height: '100%', width: '100%'}} />} {...props}>
+      <form style={{display:'flex', gap:'15px', flexDirection:'column', minHeight: 0}} action={actionUrl} method="POST">
+        {mfaView ? <>
+          {mfaView.auth_method == 'email' && <EmailRegisterView mfaView={mfaView} />}
+          {mfaView.auth_method == 'authenticator' && <AuthenticatorRegisterView mfaView={mfaView} />}
+          <Box display="flex" gap="15px">
+            <SecurityButton name="continue" value="Continue">{gettext('Continue')}</SecurityButton>
+            <DefaultButton type="submit" name="cancel" value="Cancel" style={{width: '100%'}}>{gettext('Cancel')}</DefaultButton>
+          </Box>
+        </>:<>
+          {mfaList?.map((m)=>{
+            return (
+              <Box display="flex" width="100%" key={m.label}>
+                <div style={{
+                  width: '10%', mask: `url(${m.icon})`, maskRepeat: 'no-repeat',
+                  WebkitMask: `url(${m.icon})`, WebkitMaskRepeat: 'no-repeat',
+                  backgroundColor: '#fff'
+                }}>
+                </div>
+                <div style={{width: '70%'}}>{m.label}</div>
+                <div style={{width: '20%'}}>
+                  <SecurityButton name={m.id} value={m.registered ? 'DELETE' : 'SETUP'}>{m.registered ? gettext('Delete') : gettext('Setup')}</SecurityButton>
+                </div>
+              </Box>
+            );
+          })}
+          {nextUrl != 'internal' && <SecurityButton value="Continue">{gettext('Continue')}</SecurityButton>}
+        </>}
+        <div><input type="hidden" name="next" value={nextUrl}/></div>
+      </form>
+    </BasePage>
   );
 }
 
