@@ -7,15 +7,16 @@
 //
 //////////////////////////////////////////////////////////////
 
-import { Button, ButtonGroup, makeStyles, Tooltip } from '@material-ui/core';
+import { Button, ButtonGroup, Tooltip } from '@mui/material';
 import React, { forwardRef } from 'react';
-import clsx from 'clsx';
 import PropTypes from 'prop-types';
 import CustomPropTypes from '../custom_prop_types';
 import ShortcutTitle from './ShortcutTitle';
+import { styled } from '@mui/material/styles';
 
-const useStyles = makeStyles((theme)=>({
-  primaryButton: {
+
+const StyledButton = styled(Button)(({theme}) => ({
+  '&.Buttons-primaryButton': {
     border: '1px solid '+theme.palette.primary.main,
     '&.Mui-disabled': {
       color: [theme.palette.primary.contrastText,'!important'],
@@ -25,8 +26,17 @@ const useStyles = makeStyles((theme)=>({
       backgroundColor: theme.palette.primary.hoverMain,
       borderColor: theme.palette.primary.hoverBorderColor,
     },
+    '&.Buttons-noBorderPrimary': {
+      color: theme.palette.primary.contrastText,
+      backgroundColor: theme.palette.primary.main,
+      '&:hover': {
+        color: theme.palette.primary.contrastText,
+        backgroundColor: theme.palette.primary.hoverMain,
+        borderColor: theme.palette.primary.hoverBorderColor,
+      },
+    }
   },
-  defaultButton: {
+  '&.Buttons-defaultButton': {
     backgroundColor: theme.palette.default.main,
     color: theme.palette.default.contrastText,
     border: '1px solid '+theme.palette.default.borderColor,
@@ -39,19 +49,35 @@ const useStyles = makeStyles((theme)=>({
       backgroundColor: theme.palette.default.hoverMain,
       color: theme.palette.default.hoverContrastText,
       borderColor: theme.palette.default.hoverBorderColor,
-    }
-  },
-  iconButton: {
-    minWidth: 0,
-    padding: '2px 4px',
-    '&.MuiButton-sizeSmall, &.MuiButton-outlinedSizeSmall, &.MuiButton-containedSizeSmall': {
-      padding: '1px 4px',
+    },
+    '&.Buttons-noBorder': {
+      border: 0,
+      backgroundColor: 'transparent',
+      color: theme.custom.icon.contrastText,
+      '&:hover': {
+        border: 0,
+        color: theme.custom.icon.contrastText,
+        backgroundColor: 'inherit',
+        filter: 'brightness(85%)',
+      },
+      '&.Mui-disabled': {
+        border: 0,
+      },
     },
   },
-  iconButtonDefault: {
+  '&.Buttons-iconButtonDefault': {
     borderColor: theme.custom.icon.borderColor,
     color: theme.custom.icon.contrastText,
     backgroundColor: theme.custom.icon.main,
+    height: '28px',
+    padding: '1px 4px',
+    '.MuiButtonGroup-root &': {
+      minWidth: '34px',
+
+      '&.MuiButtonGroup-firstButton:hover, &.MuiButtonGroup-middleButton:hover': {
+        borderRightColor: theme.custom.icon.borderColor,
+      },
+    },
     '&.Mui-disabled': {
       borderColor: theme.custom.icon.disabledBorderColor,
       backgroundColor: theme.custom.icon.disabledMain,
@@ -61,19 +87,26 @@ const useStyles = makeStyles((theme)=>({
       backgroundColor: theme.custom.icon.hoverMain,
       color: theme.custom.icon.hoverContrastText,
       borderColor: theme.custom.icon.borderColor,
+    }
+  },
+  '&.Buttons-iconButton': {
+    minWidth: 0,
+    padding: '2px 4px',
+    '&.MuiButton-sizeSmall, &.MuiButton-outlined.MuiButton-sizeSmall, &.MuiButton-contained.MuiButton-sizeSmall': {
     },
   },
-  splitButton: {
-    '&.MuiButton-sizeSmall, &.MuiButton-outlinedSizeSmall, &.MuiButton-containedSizeSmall': {
+  '&.Buttons-splitButton': {
+    '&.MuiButton-sizeSmall, &.MuiButton-outlined.MuiButton-sizeSmall, &.MuiButton-contained.MuiButton-sizeSmall': {
       width: '20px',
+      minWidth: 0,
       '& svg': {
         height: '0.8em',
       }
-    },
+    }
   },
-  xsButton: {
+  '&.Buttons-xsButton': {
     padding: '2px 1px',
-    height: '24px',
+    height: '24px !important',
     minWidth: '24px',
     '& .MuiSvgIcon-root': {
       height: '0.8em',
@@ -82,44 +115,22 @@ const useStyles = makeStyles((theme)=>({
       minWidth: '30px',
     }
   },
-  noBorder: {
-    border: 0,
-    backgroundColor: 'transparent',
-    color: theme.custom.icon.contrastText,
-    '&:hover': {
-      border: 0,
-      color: theme.custom.icon.contrastText,
-      backgroundColor: 'inherit',
-      filter: 'brightness(85%)',
-    },
-    '&.Mui-disabled': {
-      border: 0,
-    },
-  },
-  noBorderPrimary: {
-    color: theme.palette.primary.contrastText,
-    backgroundColor: theme.palette.primary.main,
-    '&:hover': {
-      color: theme.palette.primary.contrastText,
-      backgroundColor: theme.palette.primary.hoverMain,
-      borderColor: theme.palette.primary.hoverBorderColor,
-    },
-  }
+
 }));
 
+
 /* pgAdmin primary button */
 export const PrimaryButton = forwardRef((props, ref)=>{
   let {children, className, size, noBorder, ...otherProps} = props;
-  const classes = useStyles();
-  let allClassName = [classes.primaryButton, className];
+  let allClassName = ['Buttons-primaryButton', className];
   if(size == 'xs') {
     size = undefined;
-    allClassName.push(classes.xsButton);
+    allClassName.push('Buttons-xsButton');
   }
-  noBorder && allClassName.push(...[classes.noBorder, classes.noBorderPrimary]);
+  noBorder && allClassName.push(...['Buttons-noBorder', 'Buttons-noBorderPrimary']);
   const dataLabel = typeof(children) == 'string' ? children : undefined;
   return (
-    <Button ref={ref} size={size} className={clsx(allClassName)} data-label={dataLabel} {...otherProps} variant="contained" color="primary">{children}</Button>
+    <StyledButton ref={ref} size={size} className={allClassName.join(' ')} data-label={dataLabel} {...otherProps} color="primary" variant="contained">{children}</StyledButton>
   );
 });
 PrimaryButton.displayName = 'PrimaryButton';
@@ -133,16 +144,15 @@ PrimaryButton.propTypes = {
 /* pgAdmin default button */
 export const DefaultButton = forwardRef((props, ref)=>{
   let {children, className, size, noBorder, ...otherProps} = props;
-  const classes = useStyles();
-  let allClassName = [classes.defaultButton, className];
+  let allClassName = ['Buttons-defaultButton', className];
   if(size == 'xs') {
     size = undefined;
-    allClassName.push(classes.xsButton);
+    allClassName.push('Buttons-xsButton');
   }
-  noBorder && allClassName.push(classes.noBorder);
+  noBorder && allClassName.push('Buttons-noBorder');
   const dataLabel = typeof(children) == 'string' ? children : undefined;
   return (
-    <Button variant="outlined" color="default" ref={ref} size={size} className={clsx(allClassName)} data-label={dataLabel} {...otherProps}>{children}</Button>
+    <StyledButton variant="outlined" ref={ref} size={size} className={allClassName.join(' ')} data-label={dataLabel} color="default" {...otherProps}>{children}</StyledButton>
   );
 });
 DefaultButton.displayName = 'DefaultButton';
@@ -156,8 +166,6 @@ DefaultButton.propTypes = {
 
 /* pgAdmin Icon button, takes Icon component as input */
 export const PgIconButton = forwardRef(({icon, title, shortcut, className, splitButton, style, color, accesskey, ...props}, ref)=>{
-  const classes = useStyles();
-
   let shortcutTitle = null;
   if(accesskey || shortcut) {
     shortcutTitle = <ShortcutTitle title={title} accesskey={accesskey} shortcut={shortcut}/>;
@@ -168,7 +176,7 @@ export const PgIconButton = forwardRef(({icon, title, shortcut, className, split
     if(color == 'primary') {
       return (
         <PrimaryButton ref={ref} style={style}
-          className={clsx(classes.iconButton, (splitButton ? classes.splitButton : ''), className)}
+          className={['Buttons-iconButton', (splitButton ? 'Buttons-splitButton' : ''), className].join(' ')}
           accessKey={accesskey} data-label={title || ''} {...props}>
           {icon}
         </PrimaryButton>
@@ -176,7 +184,7 @@ export const PgIconButton = forwardRef(({icon, title, shortcut, className, split
     } else {
       return (
         <DefaultButton ref={ref} style={style}
-          className={clsx(classes.iconButton, classes.iconButtonDefault, (splitButton ? classes.splitButton : ''), className)}
+          className={['Buttons-iconButton', 'Buttons-iconButtonDefault',(splitButton ? 'Buttons-splitButton' : ''), className].join(' ')}
           accessKey={accesskey} data-label={title || ''} {...props}>
           {icon}
         </DefaultButton>
@@ -186,17 +194,18 @@ export const PgIconButton = forwardRef(({icon, title, shortcut, className, split
     return (
       <Tooltip title={shortcutTitle || title || ''} aria-label={title || ''}>
         <PrimaryButton ref={ref} style={style}
-          className={clsx(classes.iconButton, (splitButton ? classes.splitButton : ''), className)}
+          className={['Buttons-iconButton', (splitButton ? 'Buttons-splitButton' : ''), className].join(' ')}
           accessKey={accesskey} data-label={title || ''} {...props}>
           {icon}
         </PrimaryButton>
       </Tooltip>
+
     );
   } else {
     return (
       <Tooltip title={shortcutTitle || title || ''} aria-label={title || ''}>
         <DefaultButton ref={ref} style={style}
-          className={clsx(classes.iconButton, classes.iconButtonDefault, (splitButton ? classes.splitButton : ''), className)}
+          className={['Buttons-iconButton', 'Buttons-iconButtonDefault',(splitButton ? 'Buttons-splitButton' : ''), className].join(' ')}
           accessKey={accesskey} data-label={title || ''} {...props}>
           {icon}
         </DefaultButton>
@@ -220,7 +229,7 @@ PgIconButton.propTypes = {
 export const PgButtonGroup = forwardRef(({children, ...props}, ref)=>{
   /* Tooltip does not work for disabled items */
   return (
-    <ButtonGroup innerRef={ref} {...props}>
+    <ButtonGroup ref={ref} {...props}>
       {children}
     </ButtonGroup>
   );
