@@ -13,13 +13,11 @@ import copy
 import functools
 import operator
 
-from flask import render_template, request, current_app, \
-    url_for, Response
+from flask import render_template, request, current_app, Response
 from flask_babel import gettext
-from flask_security import login_required, current_user
+from pgadmin.user_login_check import pga_login_required
 from pgadmin.misc.bgprocess.processes import BatchProcess, IProcessDesc
-from pgadmin.utils import PgAdminModule, get_storage_directory, html, \
-    fs_short_path, document_dir, does_utility_exist, get_server, \
+from pgadmin.utils import PgAdminModule, does_utility_exist, get_server, \
     filename_with_file_manager_path
 from pgadmin.utils.ajax import make_json_response, bad_request, unauthorized
 
@@ -27,14 +25,16 @@ from config import PG_DEFAULT_DRIVER
 # This unused import is required as API test cases will fail if we remove it,
 # Have to identify the cause and then remove it.
 from pgadmin.model import Server, SharedServer
+from flask_security import current_user
 from pgadmin.misc.bgprocess import escape_dquotes_process_arg
-from pgadmin.utils.constants import MIMETYPE_APP_JS
-from pgadmin.tools.grant_wizard import _get_rows_for_type, \
-    get_node_sql_with_type, properties, get_data
+from pgadmin.utils.constants import MIMETYPE_APP_JS, SERVER_NOT_FOUND
+from pgadmin.tools.grant_wizard import get_data
 
 # set template path for sql scripts
 MODULE_NAME = 'backup'
 server_info = {}
+MVIEW_STR = 'materialized view'
+FOREIGN_TABLE_STR = 'foreign table'
 
 
 class BackupModule(PgAdminModule):
@@ -103,7 +103,7 @@ class BackupMessage(IProcessDesc):
             return ''
 
         for arg in _args:
-            if arg and len(arg) >= 2 and arg[:2] == '--':
+            if arg and len(arg) >= 2 and arg.startswith('--'):
                 self.cmd += ' ' + arg
             else:
                 self.cmd += cmd_arg(arg)
@@ -177,13 +177,13 @@ class BackupMessage(IProcessDesc):
 
 
 @blueprint.route("/")
-@login_required
+@pga_login_required
 def index():
     return bad_request(errormsg=gettext("This URL cannot be called directly."))
 
 
 @blueprint.route("/backup.js")
-@login_required
+@pga_login_required
 def script():
     """render own javascript"""
     return Response(
@@ -236,10 +236,13 @@ def _get_args_params_values(data, conn, backup_obj_type, backup_file, server,
             return
         val = data.get(key, default_value)
         if val:
-            val = val.split()
-            for c_val in val:
-                args.append(param)
-                args.append(c_val)
+            if isinstance(val, list):
+                for c_val in val:
+                    args.append(param)
+                    args.append(c_val)
+                return
+            args.append(param)
+            args.append(val)
 
     if backup_obj_type != 'objects':
         args.append('--database')
@@ -317,7 +320,6 @@ def _get_args_params_values(data, conn, backup_obj_type, backup_file, server,
     set_param('use_column_inserts', '--column-inserts')
     set_param('load_via_partition_root', '--load-via-partition-root',
               manager.version >= 110000)
-    set_param('with_oids', '--oids')
     set_param('enable_row_security', '--enable-row-security')
     set_value('exclude_table_data', '--exclude-table-data')
     set_value('table_and_children', '--table-and-children', None,
@@ -327,6 +329,7 @@ def _get_args_params_values(data, conn, backup_obj_type, backup_file, server,
     set_value('exclude_table_data_and_children',
               '--exclude-table-data-and-children', None,
               manager.version >= 160000)
+    set_value('exclude_table', '--exclude-table')
 
     # Disable options
     set_param('disable_trigger', '--disable-triggers',
@@ -388,7 +391,7 @@ def _get_args_params_values(data, conn, backup_obj_type, backup_file, server,
 @blueprint.route(
     '/job/<int:sid>/object', methods=['POST'], endpoint='create_object_job'
 )
-@login_required
+@pga_login_required
 def create_backup_objects_job(sid):
     """
     Args:
@@ -418,7 +421,7 @@ def create_backup_objects_job(sid):
     if server is None:
         return make_json_response(
             success=0,
-            errormsg=gettext("Could not find the specified server.")
+            errormsg=SERVER_NOT_FOUND
         )
 
     # To fetch MetaData for the server
@@ -495,7 +498,7 @@ def create_backup_objects_job(sid):
 @blueprint.route(
     '/utility_exists/<int:sid>/<backup_obj_type>', endpoint='utility_exists'
 )
-@login_required
+@pga_login_required
 def check_utility_exists(sid, backup_obj_type):
     """
     This function checks the utility file exist on the given path.
@@ -511,7 +514,7 @@ def check_utility_exists(sid, backup_obj_type):
     if server is None:
         return make_json_response(
             success=0,
-            errormsg=gettext("Could not find the specified server.")
+            errormsg=SERVER_NOT_FOUND
         )
 
     from pgadmin.utils.driver import get_driver
@@ -537,7 +540,7 @@ def check_utility_exists(sid, backup_obj_type):
 @blueprint.route(
     '/objects/<int:sid>/<int:did>/<int:scid>', endpoint='schema_objects'
 )
-@login_required
+@pga_login_required
 def objects(sid, did, scid=None):
     """
     This function returns backup objects
@@ -554,7 +557,7 @@ def objects(sid, did, scid=None):
     if server is None:
         return make_json_response(
             success=0,
-            errormsg=gettext("Could not find the specified server.")
+            errormsg=SERVER_NOT_FOUND
         )
 
     from pgadmin.utils.driver import get_driver
@@ -588,8 +591,8 @@ def objects(sid, did, scid=None):
     tree_data = {
         'table': [],
         'view': [],
-        'materialized view': [],
-        'foreign table': [],
+        MVIEW_STR: [],
+        FOREIGN_TABLE_STR: [],
         'sequence': []
     }
 
@@ -597,7 +600,7 @@ def objects(sid, did, scid=None):
 
     for data in res:
         obj_type = data['object_type'].lower()
-        if obj_type in ['table', 'view', 'materialized view', 'foreign table',
+        if obj_type in ['table', 'view', MVIEW_STR, FOREIGN_TABLE_STR,
                         'sequence']:
 
             if data['nspname'] not in schema_group:
@@ -609,8 +612,8 @@ def objects(sid, did, scid=None):
                     'is_schema': True,
                 }
             icon_data = {
-                'materialized view': 'icon-mview',
-                'foreign table': 'icon-foreign_table'
+                MVIEW_STR: 'icon-mview',
+                FOREIGN_TABLE_STR: 'icon-foreign_table'
             }
             icon = icon_data[obj_type] if obj_type in icon_data \
                 else data['icon']
@@ -629,8 +632,8 @@ def objects(sid, did, scid=None):
         for obj_type, data in ch['children'].items():
             if data:
                 icon_data = {
-                    'materialized view': 'icon-coll-mview',
-                    'foreign table': 'icon-coll-foreign_table'
+                    MVIEW_STR: 'icon-coll-mview',
+                    FOREIGN_TABLE_STR: 'icon-coll-foreign_table'
                 }
                 icon = icon_data[obj_type] if obj_type in icon_data \
                     else f'icon-coll-{obj_type.lower()}',
