@@ -12,10 +12,9 @@ SELECT obj_type, obj_name,
         ELSE 'N'
     END AS catalog_level
 FROM (
-{% if all_obj or obj_type in ['table', 'sequence', 'view', 'mview'] %}
+{% if all_obj or obj_type in ['sequence', 'view', 'mview'] %}
     SELECT
     CASE
-        WHEN c.relkind in ('r', 't') THEN 'table'
         WHEN c.relkind = 'S' THEN 'sequence'
         WHEN c.relkind = 'v' THEN 'view'
         WHEN c.relkind = 'm' THEN 'mview'
@@ -23,14 +22,12 @@ FROM (
     END::text AS obj_type, c.relname AS obj_name,
     ':schema.'|| n.oid || ':/' || n.nspname || '/' ||
     CASE
-        WHEN c.relkind in ('r', 't') THEN ':table.'
         WHEN c.relkind = 'S' THEN ':sequence.'
         WHEN c.relkind = 'v' THEN ':view.'
         WHEN c.relkind = 'm' THEN ':mview.'
         ELSE 'should not happen'
     END || c.oid ||':/' || c.relname AS obj_path, n.nspname AS schema_name,
     CASE
-        WHEN c.relkind in ('r', 't') THEN {{ show_node_prefs['table'] }}
         WHEN c.relkind = 'S' THEN {{ show_node_prefs['sequence'] }}
         WHEN c.relkind = 'v' THEN {{ show_node_prefs['view'] }}
         WHEN c.relkind = 'm' THEN {{ show_node_prefs['mview'] }}
@@ -39,9 +36,7 @@ FROM (
     FROM pg_catalog.pg_class c
     LEFT JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
     {% if all_obj %}
-    WHERE c.relkind in ('r','t','S','v','m')
-    {% elif obj_type == 'table' %}
-    WHERE c.relkind  in ('r', 't')
+    WHERE c.relkind in ('S','v','m')
     {% elif obj_type == 'sequence' %}
     WHERE c.relkind  = 'S'
     {% elif obj_type == 'view' %}
@@ -54,15 +49,67 @@ FROM (
 {% if all_obj %}
     UNION
 {% endif %}
+{% if all_obj or obj_type in ['table', 'partition'] %}
+    SELECT CASE WHEN c.relispartition THEN 'partition' ELSE 'table' END::text AS obj_type, c.relname AS obj_name,
+    ':schema.'|| n.oid || ':/' || n.nspname || '/' || (
+		WITH RECURSIVE table_path_data as (
+			select c.oid as oid, 0 as height, c.relkind,
+				CASE c.relispartition WHEN true THEN ':partition.' ELSE ':table.' END || c.oid || ':/' || c.relname as path
+			union
+			select rel.oid, pt.height+1 as height, rel.relkind,
+				CASE rel.relispartition WHEN true THEN ':partition.' ELSE ':table.' END
+				|| rel.oid || ':/' || rel.relname || '/' || pt.path as path
+			from pg_catalog.pg_class rel JOIN pg_catalog.pg_namespace nsp ON rel.relnamespace = nsp.oid
+			join pg_catalog.pg_inherits inh ON inh.inhparent = rel.oid
+			join table_path_data pt ON inh.inhrelid = pt.oid
+		)
+		select CASE WHEN relkind = 'p' THEN path ELSE ':table.' || c.oid || ':/' || c.relname END AS path
+		from table_path_data order by height desc limit 1
+	) obj_path, n.nspname AS schema_name,
+	CASE WHEN c.relispartition THEN {{ show_node_prefs['partition'] }}
+	    ELSE {{ show_node_prefs['table'] }} END AS show_node,
+    NULL AS other_info
+    FROM pg_catalog.pg_class c
+    LEFT JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
+    WHERE c.relkind in ('p','r','t')
+    {% if obj_type == 'table' %}
+    AND NOT c.relispartition
+    {% elif obj_type == 'partition' %}
+    AND c.relispartition
+    {% endif %}
+    AND CASE WHEN c.relispartition THEN {{ CATALOGS.DB_SUPPORT('n') }} ELSE true END
+{% endif %}
+{% if all_obj %}
+    UNION
+{% endif %}
 {% if all_obj or obj_type in ['index'] %}
-    SELECT 'index'::text AS obj_type, cls.relname AS obj_name,
-    ':schema.'|| n.oid || ':/' || n.nspname || '/:table.'|| tab.oid ||':/' || tab.relname || '/:index.'|| cls.oid ||':/' || cls.relname AS obj_path, n.nspname AS schema_name,
+    SELECT 'index'::text AS obj_type, cls.relname AS obj_name, ':schema.'|| n.oid || ':/' || n.nspname || '/' ||
+        case
+            when tab.relkind = 'm' then ':mview.' || tab.oid || ':' || '/' || tab.relname
+            WHEN tab.relkind in ('r', 't', 'p') THEN
+                (
+                    WITH RECURSIVE table_path_data as (
+                        select tab.oid as oid, 0 as height, tab.relkind,
+                            CASE tab.relispartition WHEN true THEN ':partition.' ELSE ':table.' END || tab.oid || ':/' || tab.relname as path
+                        union
+                        select rel.oid, pt.height+1 as height, rel.relkind,
+                            CASE rel.relispartition WHEN true THEN ':partition.' ELSE ':table.' END
+                            || rel.oid || ':/' || rel.relname || '/' || pt.path as path
+                        from pg_catalog.pg_class rel JOIN pg_catalog.pg_namespace nsp ON rel.relnamespace = nsp.oid
+                        join pg_catalog.pg_inherits inh ON inh.inhparent = rel.oid
+                        join table_path_data pt ON inh.inhrelid = pt.oid
+                    )
+                    select CASE WHEN relkind = 'p' THEN path ELSE ':table.' || tab.oid || ':/' || tab.relname END AS path
+                    from table_path_data order by height desc limit 1
+               )
+        end
+        || '/:index.'|| cls.oid ||':/' || cls.relname AS obj_path, n.nspname AS schema_name,
     {{ show_node_prefs['index'] }} AS show_node, NULL AS other_info
     FROM pg_catalog.pg_index idx
     JOIN pg_catalog.pg_class cls ON cls.oid=indexrelid
     JOIN pg_catalog.pg_class tab ON tab.oid=indrelid
     JOIN pg_catalog.pg_namespace n ON n.oid=tab.relnamespace
-    LEFT JOIN pg_catalog.pg_depend dep ON (dep.classid = cls.tableoid AND dep.objid = cls.oid AND dep.refobjsubid = '0' AND dep.refclassid=(SELECT oid FROM pg_class WHERE relname='pg_constraint') AND dep.deptype='i')
+    LEFT JOIN pg_catalog.pg_depend dep ON (dep.classid = cls.tableoid AND dep.objid = cls.oid AND dep.refobjsubid = '0' AND dep.refclassid=(SELECT oid FROM pg_catalog.pg_class WHERE relname='pg_constraint') AND dep.deptype='i')
     LEFT OUTER JOIN pg_catalog.pg_constraint con ON (con.tableoid = dep.refclassid AND con.oid = dep.refobjid)
     LEFT OUTER JOIN pg_catalog.pg_description des ON des.objoid=cls.oid
     LEFT OUTER JOIN pg_catalog.pg_description desp ON (desp.objoid=con.oid AND desp.objsubid = 0)
@@ -108,15 +155,16 @@ FROM (
     select 'column'::text AS obj_type, a.attname AS obj_name,
     ':schema.'||n.oid||':/' || n.nspname || '/' ||
     case
-        WHEN t.relkind in ('r', 't') THEN ':table.'
+        WHEN t.relkind in ('r', 't', 'p') THEN ':table.'
         WHEN t.relkind = 'v' THEN ':view.'
         WHEN t.relkind = 'm' THEN ':mview.'
         else 'should not happen'
     end || t.oid || ':/' || t.relname || '/:column.'|| a.attnum ||':/' || a.attname AS obj_path, n.nspname AS schema_name,
     {{ show_node_prefs['column'] }} AS show_node, NULL AS other_info
     from pg_catalog.pg_attribute a
-    inner join pg_catalog.pg_class t on a.attrelid = t.oid and t.relkind in ('r', 't','v','m')
+    inner join pg_catalog.pg_class t on a.attrelid = t.oid and t.relkind in ('r','t','p','v','m')
     left join pg_catalog.pg_namespace n on t.relnamespace = n.oid where a.attnum > 0
+    and not t.relispartition
 {% endif %}
 {% if all_obj %}
     UNION
@@ -131,7 +179,22 @@ FROM (
         WHEN c.contype = 'x' THEN  'exclusion_constraint'
     END::text AS obj_type,
     case when tf.relname is null then c.conname else c.conname || ' -> ' || tf.relname end AS obj_name,
-    ':schema.'||n.oid||':/' || n.nspname||'/:table.'|| t.oid || ':/'||t.relname||
+    ':schema.'||n.oid||':/' || n.nspname||'/'||
+    (
+		WITH RECURSIVE table_path_data as (
+			select t.oid as oid, 0 as height, t.relkind,
+				CASE t.relispartition WHEN true THEN ':partition.' ELSE ':table.' END || t.oid || ':/' || t.relname as path
+			union
+			select rel.oid, pt.height+1 as height, rel.relkind,
+				CASE rel.relispartition WHEN true THEN ':partition.' ELSE ':table.' END
+				|| rel.oid || ':/' || rel.relname || '/' || pt.path as path
+			from pg_catalog.pg_class rel JOIN pg_catalog.pg_namespace nsp ON rel.relnamespace = nsp.oid
+			join pg_catalog.pg_inherits inh ON inh.inhparent = rel.oid
+			join table_path_data pt ON inh.inhrelid = pt.oid
+		)
+		select CASE WHEN relkind = 'p' THEN path ELSE ':table.' || t.oid || ':/' || t.relname END AS path
+		from table_path_data order by height desc limit 1
+	) ||
     CASE
         WHEN c.contype = 'c' THEN  '/:check_constraint.' ||c.oid
         WHEN c.contype = 'f' THEN  '/:foreign_key.' ||c.oid
@@ -164,16 +227,31 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['rule'] %}
-    select 'rule'::text AS obj_type, r.rulename AS obj_name, ':schema.'||n.oid||':/' || n.nspname||
+    select 'rule'::text AS obj_type, r.rulename AS obj_name, ':schema.'||n.oid||':/' || n.nspname|| '/' ||
             case
-                WHEN t.relkind in ('r', 't') THEN '/:table.'
-                when t.relkind = 'v' then '/:view.'
-                else 'should not happen'
-            end || t.oid || ':/' || t.relname ||'/:rule.'||r.oid||':/'|| r.rulename AS obj_path,
+                when t.relkind = 'v' then ':view.' || t.oid || ':' || '/' || t.relname
+                WHEN t.relkind in ('r', 't', 'p') THEN
+                    (
+                        WITH RECURSIVE table_path_data as (
+                            select t.oid as oid, 0 as height, t.relkind,
+                                CASE t.relispartition WHEN true THEN ':partition.' ELSE ':table.' END || t.oid || ':/' || t.relname as path
+                            union
+                            select rel.oid, pt.height+1 as height, rel.relkind,
+                                CASE rel.relispartition WHEN true THEN ':partition.' ELSE ':table.' END
+                                || rel.oid || ':/' || rel.relname || '/' || pt.path as path
+                            from pg_catalog.pg_class rel JOIN pg_catalog.pg_namespace nsp ON rel.relnamespace = nsp.oid
+                            join pg_catalog.pg_inherits inh ON inh.inhparent = rel.oid
+                            join table_path_data pt ON inh.inhrelid = pt.oid
+                        )
+                        select CASE WHEN relkind = 'p' THEN path ELSE ':table.' || t.oid || ':/' || t.relname END AS path
+                        from table_path_data order by height desc limit 1
+                    )
+            end
+            ||'/:rule.'||r.oid||':/'|| r.rulename AS obj_path,
             n.nspname AS schema_name,
             {{ show_node_prefs['rule'] }} AS show_node, NULL AS other_info
             from pg_catalog.pg_rewrite r
-    inner join pg_catalog.pg_class t on r.ev_class = t.oid and t.relkind in ('r', 't','v')
+    inner join pg_catalog.pg_class t on r.ev_class = t.oid and t.relkind in ('r','t','p','v')
     left join pg_catalog.pg_namespace n on t.relnamespace = n.oid
     where {{ CATALOGS.DB_SUPPORT('n') }}
 {% endif %}
@@ -181,15 +259,29 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['trigger'] %}
-    select 'trigger'::text AS obj_type, tr.tgname AS obj_name, ':schema.'||n.oid||':/' || n.nspname||
-            case
-                WHEN t.relkind in ('r', 't') THEN '/:table.'
-                when t.relkind = 'v' then '/:view.'
-                else 'should not happen'
-            end || t.oid || ':/' || t.relname || '/:trigger.'|| tr.oid || ':/' || tr.tgname AS obj_path, n.nspname AS schema_name,
-            {{ show_node_prefs['trigger'] }} AS show_node, NULL AS other_info
-            from pg_catalog.pg_trigger tr
-    inner join pg_catalog.pg_class t on tr.tgrelid = t.oid and t.relkind in ('r', 't', 'v')
+    select 'trigger'::text AS obj_type, tr.tgname AS obj_name, ':schema.'||n.oid||':/' || n.nspname|| '/' ||
+        case
+            when t.relkind = 'v' then ':view.' || t.oid || ':' || '/' || t.relname
+            WHEN t.relkind in ('r', 't', 'p') THEN
+            (
+                WITH RECURSIVE table_path_data as (
+                    select t.oid as oid, 0 as height, t.relkind,
+                        CASE t.relispartition WHEN true THEN ':partition.' ELSE ':table.' END || t.oid || ':/' || t.relname as path
+                    union
+                    select rel.oid, pt.height+1 as height, rel.relkind,
+                        CASE rel.relispartition WHEN true THEN ':partition.' ELSE ':table.' END
+                        || rel.oid || ':/' || rel.relname || '/' || pt.path as path
+                    from pg_catalog.pg_class rel JOIN pg_catalog.pg_namespace nsp ON rel.relnamespace = nsp.oid
+                    join pg_catalog.pg_inherits inh ON inh.inhparent = rel.oid
+                    join table_path_data pt ON inh.inhrelid = pt.oid
+                )
+                select CASE WHEN relkind = 'p' THEN path ELSE ':table.' || t.oid || ':/' || t.relname END AS path
+                from table_path_data order by height desc limit 1
+            )
+        end || '/:trigger.'|| tr.oid || ':/' || tr.tgname AS obj_path, n.nspname AS schema_name,
+        {{ show_node_prefs['trigger'] }} AS show_node, NULL AS other_info
+        from pg_catalog.pg_trigger tr
+    inner join pg_catalog.pg_class t on tr.tgrelid = t.oid and t.relkind in ('r', 't', 'p', 'v')
     left join pg_catalog.pg_namespace n on t.relnamespace = n.oid
     where tr.tgisinternal = false
     and {{ CATALOGS.DB_SUPPORT('n') }}
@@ -228,6 +320,26 @@ FROM (
 {% if all_obj %}
     UNION
 {% endif %}
+
+{% if all_obj or obj_type in ['publication'] %}
+    SELECT 'publication'::text AS obj_type, pubname AS obj_name, ':publication.'||pub.oid||':/' || pubname AS obj_path, ''::text AS schema_name,
+    {{ show_node_prefs['publication'] }} AS show_node, NULL AS other_info
+    FROM pg_catalog.pg_publication pub
+{% endif %}
+{% if all_obj %}
+    UNION
+{% endif %}
+
+{% if 'subscription' not in skip_obj_type%}
+{% if all_obj or obj_type in ['subscription'] %}
+    SELECT 'subscription'::text AS obj_type, subname AS obj_name, ':subscription.'||pub.oid||':/' || subname AS obj_path, ''::text AS schema_name,
+    {{ show_node_prefs['subscription'] }} AS show_node, NULL AS other_info
+    FROM pg_catalog.pg_subscription pub
+{% endif %}
+{% if all_obj %}
+    UNION
+{% endif %}
+{% endif %}
 {% if all_obj or obj_type in ['language'] %}
     SELECT 'language'::text AS obj_type, lanname AS obj_name, ':language.'||lan.oid||':/' || lanname AS obj_path, ''::text AS schema_name,
     {{ show_node_prefs['language'] }} AS show_node, NULL AS other_info
@@ -248,7 +360,7 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['fts_dictionary'] %}
-    SELECT 'fts_dictionary'::text AS obj_type, dict.dictname AS obj_name, ':schema.'||ns.oid||':/' || ns.nspname || '/:fts_dictionary.'||dict.oid||':/' || dict.dictname AS obj_path, ns.nspname AS schema_name,
+    SELECT 'fts_dictionary' AS obj_type, dict.dictname AS obj_name, ':schema.'||ns.oid||':/' || ns.nspname || '/:fts_dictionary.'||dict.oid||':/' || dict.dictname AS obj_path, ns.nspname AS schema_name,
     {{ show_node_prefs['fts_dictionary'] }} AS show_node, NULL AS other_info
     FROM pg_catalog.pg_ts_dict dict
     left join pg_catalog.pg_namespace ns on dict.dictnamespace = ns.oid
@@ -258,7 +370,7 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['fts_parser'] %}
-    SELECT 'fts_parser'::text AS obj_type, prs.prsname AS obj_name, ':schema.'||ns.oid||':/' || ns.nspname || '/:fts_parser.'||prs.oid||':/' || prs.prsname AS obj_path, ns.nspname AS schema_name,
+    SELECT 'fts_parser' AS obj_type, prs.prsname AS obj_name, ':schema.'||ns.oid||':/' || ns.nspname || '/:fts_parser.'||prs.oid||':/' || prs.prsname AS obj_path, ns.nspname AS schema_name,
     {{ show_node_prefs['fts_parser'] }} AS show_node, NULL AS other_info
     FROM pg_catalog.pg_ts_parser prs
     left join pg_catalog.pg_namespace ns on prs.prsnamespace = ns.oid
@@ -268,7 +380,7 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['fts_template'] %}
-    SELECT 'fts_template'::text AS obj_type, tmpl.tmplname AS obj_name, ':schema.'||ns.oid||':/' || ns.nspname || '/:fts_template.'||tmpl.oid||':/' || tmpl.tmplname AS obj_path, ns.nspname AS schema_name,
+    SELECT 'fts_template' AS obj_type, tmpl.tmplname AS obj_name, ':schema.'||ns.oid||':/' || ns.nspname || '/:fts_template.'||tmpl.oid||':/' || tmpl.tmplname AS obj_path, ns.nspname AS schema_name,
     {{ show_node_prefs['fts_template'] }} AS show_node, NULL AS other_info
     FROM pg_catalog.pg_ts_template tmpl
     left join pg_catalog.pg_namespace ns on tmpl.tmplnamespace = ns.oid
@@ -278,7 +390,7 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['domain'] %}
-    select 'domain'::text AS obj_type, t.typname AS obj_name, ':schema.'||n.oid||':/' || n.nspname || '/:domain.'||t.oid||':/' || t.typname AS obj_path, n.nspname AS schema_name,
+    select 'domain' AS obj_type, t.typname AS obj_name, ':schema.'||n.oid||':/' || n.nspname || '/:domain.'||t.oid||':/' || t.typname AS obj_path, n.nspname AS schema_name,
     {{ show_node_prefs['domain'] }} AS show_node, NULL AS other_info
     from pg_catalog.pg_type t
     inner join pg_catalog.pg_namespace n on t.typnamespace = n.oid
@@ -289,7 +401,7 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['domain_constraints'] %}
-    SELECT 'domain_constraints'::text AS obj_type,
+    SELECT 'domain_constraints' AS obj_type,
         c.conname AS obj_name, ':schema.'||n.oid||':/' || n.nspname || '/:domain.'||t.oid||':/' || t.typname || '/:domain_constraints.'||c.oid||':/' || c.conname AS obj_path,
         n.nspname AS schema_name,
         {{ show_node_prefs['domain_constraints'] }} AS show_node, NULL AS other_info
@@ -303,7 +415,7 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['foreign_data_wrapper'] %}
-    select 'foreign_data_wrapper'::text AS obj_type, fdwname AS obj_name, ':foreign_data_wrapper.'||oid||':/' || fdwname AS obj_path, ''::text AS schema_name,
+    select 'foreign_data_wrapper' AS obj_type, fdwname AS obj_name, ':foreign_data_wrapper.'||oid||':/' || fdwname AS obj_path, ''::text AS schema_name,
     {{ show_node_prefs['foreign_data_wrapper'] }} AS show_node, NULL AS other_info
     from pg_catalog.pg_foreign_data_wrapper
 {% endif %}
@@ -311,7 +423,7 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['foreign_server'] %}
-    select 'foreign_server'::text AS obj_type, sr.srvname AS obj_name, ':foreign_data_wrapper.'||fdw.oid||':/' || fdw.fdwname || '/:foreign_server.'||sr.oid||':/' || sr.srvname AS obj_path, ''::text AS schema_name,
+    select 'foreign_server' AS obj_type, sr.srvname AS obj_name, ':foreign_data_wrapper.'||fdw.oid||':/' || fdw.fdwname || '/:foreign_server.'||sr.oid||':/' || sr.srvname AS obj_path, ''::text AS schema_name,
     {{ show_node_prefs['foreign_server'] }} AS show_node, NULL AS other_info
     from pg_catalog.pg_foreign_server sr
     inner join pg_catalog.pg_foreign_data_wrapper fdw on sr.srvfdw = fdw.oid
@@ -320,7 +432,7 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['user_mapping'] %}
-    select 'user_mapping'::text AS obj_type, um.usename AS obj_name, ':foreign_data_wrapper.'||fdw.oid||':/' || fdw.fdwname || '/:foreign_server.'||sr.oid||':/' || sr.srvname || '/:user_mapping.'||um.umid||':/' || um.usename AS obj_path, ''::text AS schema_name,
+    select 'user_mapping' AS obj_type, um.usename AS obj_name, ':foreign_data_wrapper.'||fdw.oid||':/' || fdw.fdwname || '/:foreign_server.'||sr.oid||':/' || sr.srvname || '/:user_mapping.'||um.umid||':/' || um.usename AS obj_path, ''::text AS schema_name,
     {{ show_node_prefs['user_mapping'] }} AS show_node, NULL AS other_info
     from pg_catalog.pg_user_mappings um
     inner join pg_catalog.pg_foreign_server sr on um.srvid = sr.oid
@@ -330,7 +442,7 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['foreign_table'] %}
-    select 'foreign_table'::text AS obj_type, c.relname AS obj_name, ':schema.'||ns.oid||':/' || ns.nspname || '/:foreign_table.'||c.oid||':/' || c.relname AS obj_path, ns.nspname AS schema_name,
+    select 'foreign_table' AS obj_type, c.relname AS obj_name, ':schema.'||ns.oid||':/' || ns.nspname || '/:foreign_table.'||c.oid||':/' || c.relname AS obj_path, ns.nspname AS schema_name,
     {{ show_node_prefs['foreign_table'] }} AS show_node, NULL AS other_info
     from pg_catalog.pg_foreign_table ft
     inner join pg_catalog.pg_class c on ft.ftrelid = c.oid
@@ -341,7 +453,7 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['extension'] %}
-    select 'extension'::text AS obj_type, x.extname AS obj_name, ':extension.'||x.oid||':/' || x.extname AS obj_path, ''::text AS schema_name,
+    select 'extension' AS obj_type, x.extname AS obj_name, ':extension.'||x.oid||':/' || x.extname AS obj_path, ''::text AS schema_name,
     {{ show_node_prefs['extension'] }} AS show_node, NULL AS other_info
     FROM pg_catalog.pg_extension x
     JOIN pg_catalog.pg_namespace n on x.extnamespace=n.oid
@@ -351,7 +463,7 @@ FROM (
     UNION
 {% endif %}
 {% if all_obj or obj_type in ['collation'] %}
-    SELECT 'collation'::text AS obj_type, c.collname AS obj_name, ':schema.'||n.oid||':/' || n.nspname || '/:collation.'||c.oid||':/' || c.collname AS obj_path, n.nspname AS schema_name,
+    SELECT 'collation' AS obj_type, c.collname AS obj_name, ':schema.'||n.oid||':/' || n.nspname || '/:collation.'||c.oid||':/' || c.collname AS obj_path, n.nspname AS schema_name,
     {{ show_node_prefs['collation'] }} AS show_node, NULL AS other_info
     FROM pg_catalog.pg_collation c
     JOIN pg_catalog.pg_namespace n ON n.oid=c.collnamespace
@@ -360,6 +472,37 @@ FROM (
 {% if all_obj %}
     UNION
 {% endif %}
+{% if all_obj or obj_type in ['row_security_policy'] %}
+    select 'row_security_policy'::text AS obj_type, pl.polname AS obj_name, ':schema.'||n.oid||':/' || n.nspname|| '/' ||
+            case
+                WHEN t.relkind in ('r', 't', 'p') THEN
+                    (
+                        WITH RECURSIVE table_path_data as (
+                            select t.oid as oid, 0 as height, t.relkind,
+                                CASE t.relispartition WHEN true THEN ':partition.' ELSE ':table.' END || t.oid || ':/' || t.relname as path
+                            union
+                            select rel.oid, pt.height+1 as height, rel.relkind,
+                                CASE rel.relispartition WHEN true THEN ':partition.' ELSE ':table.' END
+                                || rel.oid || ':/' || rel.relname || '/' || pt.path as path
+                            from pg_catalog.pg_class rel JOIN pg_catalog.pg_namespace nsp ON rel.relnamespace = nsp.oid
+                            join pg_catalog.pg_inherits inh ON inh.inhparent = rel.oid
+                            join table_path_data pt ON inh.inhrelid = pt.oid
+                        )
+                        select CASE WHEN relkind = 'p' THEN path ELSE ':table.' || t.oid || ':/' || t.relname END AS path
+                        from table_path_data order by height desc limit 1
+                    )
+            end
+            ||'/:row_security_policy.'|| pl.oid ||':/'|| pl.polname AS obj_path, n.nspname AS schema_name,
+            {{ show_node_prefs['row_security_policy'] }} AS show_node, NULL AS other_info
+            FROM pg_catalog.pg_policy pl
+    JOIN pg_catalog.pg_class t on pl.polrelid = t.oid and t.relkind in ('r','t','p')
+    JOIN pg_catalog.pg_policies rw ON (pl.polname=rw.policyname AND t.relname=rw.tablename)
+    JOIN pg_catalog.pg_namespace n on t.relnamespace = n.oid
+    where {{ CATALOGS.DB_SUPPORT('n') }}
+{% endif %}
+{% if all_obj %}
+    UNION
+{% endif %}
 {% if all_obj or obj_type in ['aggregate'] %}
     SELECT 'aggregate' AS obj_type, pr.proname AS obj_name,
     ':schema.'|| ns.oid || ':/' || ns.nspname || '/' || ':aggregate.' || ag.aggfnoid::oid ||':/' || pr.proname AS obj_path,
