@@ -19,7 +19,7 @@ import 'pgadmin.tools.user_management';
 import 'pgadmin.tools.file_manager';
 import gettext from 'sources/gettext';
 import React from 'react';
-import ReactDOM from 'react-dom';
+import ReactDOM from 'react-dom/client';
 import QueryToolComponent from './components/QueryToolComponent';
 import ModalProvider from '../../../../static/js/helpers/ModalProvider';
 import Theme from '../../../../static/js/Theme';
@@ -51,7 +51,7 @@ export default class SQLEditor {
   viewMenuEnabled(obj) {
     let isEnabled = (() => {
       if (!_.isUndefined(obj) && !_.isNull(obj))
-        return (_.indexOf(this.SUPPORTED_NODES, obj._type) !== -1 ? true : false);
+        return (_.indexOf(this.SUPPORTED_NODES, obj._type) !== -1);
       else
         return false;
     })();
@@ -228,7 +228,8 @@ export default class SQLEditor {
     );
     pgAdmin.Browser.keyboardNavigation.init();
     await listenPreferenceBroadcast();
-    ReactDOM.render(
+    const root = ReactDOM.createRoot(container);
+    root.render(
       <Theme>
         <PgAdminContext.Provider value={pgAdmin}>
           <ModalProvider>
@@ -237,8 +238,7 @@ export default class SQLEditor {
               qtPanelId={`${BROWSER_PANELS.QUERY_TOOL}_${params.trans_id}`} selectedNodeInfo={selectedNodeInfo}/>
           </ModalProvider>
         </PgAdminContext.Provider>
-      </Theme>,
-      container
+      </Theme>
     );
   }
 }
