@@ -19,8 +19,8 @@ import { Messages } from './sections/Messages';
 import getApiInstance, {callFetch, parseApiError} from '../../../../../static/js/api_instance';
 import url_for from 'sources/url_for';
 import { PANELS, QUERY_TOOL_EVENTS, CONNECTION_STATUS, MAX_QUERY_LENGTH } from './QueryToolConstants';
-import { useInterval } from '../../../../../static/js/custom_hooks';
-import { Box } from '@material-ui/core';
+import { useBeforeUnload, useInterval } from '../../../../../static/js/custom_hooks';
+import { Box } from '@mui/material';
 import { getDatabaseLabel, getTitle, setQueryToolDockerTitle } from '../sqleditor_title';
 import gettext from 'sources/gettext';
 import NewConnectionDialog from './dialogs/NewConnectionDialog';
@@ -50,6 +50,21 @@ function initConnection(api, params, passdata) {
   return api.post(url_for('NODE-server.connect_id', params), passdata);
 }
 
+export function getRandomName(existingNames) {
+  const maxNumber = existingNames.reduce((max, name) => {
+    const match = name.match(/\d+$/); // Extract the number from the name
+    if (match) {
+      const number = parseInt(match[0], 10);
+      return number > max ? number : max;
+    }
+    return max;
+  }, 0);
+
+  // Generate the new name
+  const newName = `Macro ${maxNumber + 1}`;
+  return newName;
+}
+
 function setPanelTitle(docker, panelId, title, qtState, dirty=false) {
   if(qtState.current_file) {
     title = qtState.current_file.split('\\').pop().split('/').pop();
@@ -71,15 +86,10 @@ function setPanelTitle(docker, panelId, title, qtState, dirty=false) {
     docker.setInternalAttrs(panelId, {
       isDirty: dirty,
     });
-    setQueryToolDockerTitle(docker, panelId, true, title, qtState.current_file ? true : false);
+    setQueryToolDockerTitle(docker, panelId, true, title, qtState.current_file);
   }
 }
 
-function onBeforeUnload(e) {
-  e.preventDefault();
-  e.returnValue = 'prevent';
-}
-
 const FIXED_PREF = {
   find: {
     'control': true,
@@ -154,7 +164,7 @@ const FIXED_PREF = {
 export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedNodeInfo, qtPanelDocker, qtPanelId, eventBusObj}) {
   const containerRef = React.useRef(null);
   const preferencesStore = usePreferences();
-  const [qtState, _setQtState] = useState({
+  const [qtState, setQtState] = useState({
     preferences: {
       browser: preferencesStore.getPreferencesForModule('browser'),
       sqleditor: {...preferencesStore.getPreferencesForModule('sqleditor'), ...FIXED_PREF},
@@ -172,7 +182,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
     params: {
       ...params,
       title: _.unescape(params.title),
-      is_query_tool: params.is_query_tool == 'true' ? true : false,
+      is_query_tool: params.is_query_tool == 'true',
       node_name: retrieveNodeName(selectedNodeInfo),
       dbname: _.unescape(params.database_name) || getDatabaseLabel(selectedNodeInfo)
     },
@@ -187,15 +197,17 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
       bgcolor: params.bgcolor,
       conn_title: getTitle(
         pgAdmin, null, selectedNodeInfo, true, _.unescape(params.server_name), _.unescape(params.database_name) || getDatabaseLabel(selectedNodeInfo),
-        _.unescape(params.role) || _.unescape(params.user), params.is_query_tool == 'true' ? true : false),
+        _.unescape(params.role) || _.unescape(params.user), params.is_query_tool == 'true'),
       server_name: _.unescape(params.server_name),
       database_name: _.unescape(params.database_name) || getDatabaseLabel(selectedNodeInfo),
       is_selected: true,
     }],
+    editor_disabled:true
   });
+  const [selectedText, setSelectedText] = useState('');
 
-  const setQtState = (state)=>{
-    _setQtState((prev)=>({...prev,...evalFunc(null, state, prev)}));
+  const setQtStatePartial = (state)=>{
+    setQtState((prev)=>({...prev,...evalFunc(null, state, prev)}));
   };
   const isDirtyRef = useRef(false); // usefull when conn change.
   const eventBus = useRef(eventBusObj || (new EventBus()));
@@ -216,12 +228,12 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
     try {
       let {data: respData} = await fetchConnectionStatus(api, qtState.params.trans_id);
       if(respData.data) {
-        setQtState({
+        setQtStatePartial({
           connected: true,
           connection_status: respData.data.status,
         });
       } else {
-        setQtState({
+        setQtStatePartial({
           connected: false,
           connection_status: null,
           connection_status_msg: gettext('An unexpected error occurred - ensure you are logged into the application.')
@@ -232,7 +244,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
       }
     } catch (error) {
       console.error(error);
-      setQtState({
+      setQtStatePartial({
         connected: false,
         connection_status: null,
         connection_status_msg: parseApiError(error),
@@ -250,7 +262,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
             {
               maximizable: true,
               tabs: [
-                LayoutDocker.getPanel({id: PANELS.QUERY, title: gettext('Query'), content: <Query />}),
+                LayoutDocker.getPanel({id: PANELS.QUERY, title: gettext('Query'), content: <Query  onTextSelect={(text) => setSelectedText(text)}/>}),
                 LayoutDocker.getPanel({id: PANELS.HISTORY, title: gettext('Query History'), content: <QueryHistory />,
                   cached: undefined}),
               ],
@@ -296,23 +308,28 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
     },
   };
 
-  const getSQLScript = ()=>{
+  const getSQLScript = () => {
     // Fetch the SQL for Scripts (eg: CREATE/UPDATE/DELETE/SELECT)
-    // Call AJAX only if script type url is present
-    if(qtState.params.is_query_tool && qtState.params.query_url) {
+    // Call AJAX only if script type URL is present
+    if (qtState.params.is_query_tool && qtState.params.query_url) {
       api.get(qtState.params.query_url)
-        .then((res)=>{
+        .then((res) => {
           eventBus.current.fireEvent(QUERY_TOOL_EVENTS.EDITOR_SET_SQL, res.data);
+          setQtStatePartial({ editor_disabled: false });
         })
-        .catch((err)=>{
+        .catch((err) => {
           eventBus.current.fireEvent(QUERY_TOOL_EVENTS.HANDLE_API_ERROR, err);
+          setQtStatePartial({ editor_disabled: true });
         });
-    } else if(qtState.params.sql_id) {
+    } else if (qtState.params.sql_id) {
       let sqlValue = localStorage.getItem(qtState.params.sql_id);
       localStorage.removeItem(qtState.params.sql_id);
-      if(sqlValue) {
+      if (sqlValue) {
         eventBus.current.fireEvent(QUERY_TOOL_EVENTS.EDITOR_SET_SQL, sqlValue);
       }
+      setQtStatePartial({ editor_disabled: false });
+    } else {
+      setQtStatePartial({ editor_disabled: false });
     }
   };
 
@@ -341,7 +358,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
       dbname: selectedConn.database_name
     } : JSON.stringify(qtState.params.sql_filter))
       .then(()=>{
-        setQtState({
+        setQtStatePartial({
           connected: true,
           connected_once: true,
           obtaining_conn: false,
@@ -357,7 +374,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
               initializeQueryTool();
             })
             .catch((kberr)=>{
-              setQtState({
+              setQtStatePartial({
                 connected: false,
                 obtaining_conn: false,
               });
@@ -367,14 +384,14 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
           connectServerModal(error.response?.data?.result, (passwordData)=>{
             initializeQueryTool(passwordData.password);
           }, ()=>{
-            setQtState({
+            setQtStatePartial({
               connected: false,
               obtaining_conn: false,
               connection_status_msg: gettext('Not Connected'),
             });
           });
         } else {
-          setQtState({
+          setQtStatePartial({
             connected: false,
             obtaining_conn: false,
           });
@@ -383,6 +400,17 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
       });
   };
 
+  const {forceClose} = useBeforeUnload({
+    enabled: qtState.preferences.browser.confirm_on_refresh_close,
+    isNewTab: qtState.is_new_tab,
+    beforeClose: ()=>{
+      eventBus.current.fireEvent(QUERY_TOOL_EVENTS.WARN_SAVE_DATA_CLOSE);
+    },
+    closePanel: ()=>{
+      qtPanelDocker.close(qtPanelId, true);
+    }
+  });
+
   useEffect(()=>{
     getSQLScript();
     initializeQueryTool();
@@ -392,16 +420,15 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
     });
 
     eventBus.current.registerListener(QUERY_TOOL_EVENTS.SET_CONNECTION_STATUS, (status)=>{
-      setQtState({connection_status: status});
+      setQtStatePartial({connection_status: status});
     });
 
     eventBus.current.registerListener(QUERY_TOOL_EVENTS.FORCE_CLOSE_PANEL, ()=>{
-      qtPanelDocker.close(qtPanelId, true);
+      forceClose();
     });
 
     qtPanelDocker.eventBus.registerListener(LAYOUT_EVENTS.CLOSING, (id)=>{
       if(qtPanelId == id) {
-        window.removeEventListener('beforeunload', onBeforeUnload);
         eventBus.current.fireEvent(QUERY_TOOL_EVENTS.WARN_SAVE_DATA_CLOSE);
       }
     });
@@ -409,7 +436,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
     qtPanelDocker.eventBus.registerListener(LAYOUT_EVENTS.ACTIVE, _.debounce((currentTabId)=>{
       /* Focus the appropriate panel on visible */
       if(qtPanelId == currentTabId) {
-        setQtState({is_visible: true});
+        setQtStatePartial({is_visible: true});
 
         if(docker.current.isTabVisible(PANELS.QUERY)) {
           docker.current.focus(PANELS.QUERY);
@@ -419,23 +446,23 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
 
         eventBus.current.fireEvent(QUERY_TOOL_EVENTS.GOTO_LAST_SCROLL);
       } else {
-        setQtState({is_visible: false});
+        setQtStatePartial({is_visible: false});
       }
     }, 100));
 
     /* If the tab or window is not visible, applicable for open in new tab */
     document.addEventListener('visibilitychange', function() {
       if(document.hidden) {
-        setQtState({is_visible: false});
+        setQtStatePartial({is_visible: false});
       } else {
-        setQtState({is_visible: true});
+        setQtStatePartial({is_visible: true});
       }
     });
   }, []);
 
   useEffect(() => usePreferences.subscribe(
     state => {
-      setQtState({preferences: {
+      setQtStatePartial({preferences: {
         browser: state.getPreferencesForModule('browser'),
         sqleditor: {...state.getPreferencesForModule('sqleditor'), ...FIXED_PREF},
         graphs: state.getPreferencesForModule('graphs'),
@@ -528,7 +555,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
   useEffect(()=>{
     const fileDone = (fileName, success=true)=>{
       if(success) {
-        setQtState({
+        setQtStatePartial({
           current_file: fileName,
         });
         isDirtyRef.current = false;
@@ -539,7 +566,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
     const events = [
       [QUERY_TOOL_EVENTS.TRIGGER_LOAD_FILE, ()=>{
         let fileParams = {
-          'supported_types': ['*', 'sql'], // file types allowed
+          'supported_types': ['sql', '*'], // file types allowed
           'dialog_type': 'select_file', // open select file dialog
         };
         pgAdmin.Tools.FileManager.show(fileParams, (fileName, storage)=>{
@@ -551,7 +578,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
           eventBus.current.fireEvent(QUERY_TOOL_EVENTS.SAVE_FILE, qtState.current_file);
         } else {
           let fileParams = {
-            'supported_types': ['*', 'sql'],
+            'supported_types': ['sql', '*'],
             'dialog_type': 'create_file',
             'dialog_title': 'Save File',
             'btn_primary': 'Save',
@@ -608,25 +635,12 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
     });
   };
 
-  useEffect(()=> {
-    // Add beforeunload event if "Confirm on close or refresh" option is enabled in the preferences.
-    if(qtState.preferences.browser.confirm_on_refresh_close){
-      window.addEventListener('beforeunload', onBeforeUnload);
-    } else {
-      window.removeEventListener('beforeunload', onBeforeUnload);
-    }
-
-    return () => {
-      window.removeEventListener('beforeunload', onBeforeUnload);
-    };
-  }, [qtState.preferences.browser]);
-
   const updateQueryToolConnection = (connectionData, isNew=false)=>{
     let currSelectedConn = _.find(qtState.connection_list, (c)=>c.is_selected);
     let currConnected = qtState.connected;
 
     const selectConn = (newConnData, connected=false, obtainingConn=true)=>{
-      setQtState((prevQtState)=>{
+      setQtStatePartial((prevQtState)=>{
         let newConnList = [...prevQtState.connection_list];
         /* If new, add to the list */
         if(isNew) {
@@ -665,7 +679,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
           if(isNew) {
             selectConn(connectionData);
           }
-          setQtState((prev)=>{
+          setQtStatePartial((prev)=>{
             return {
               params: {
                 ...prev.params,
@@ -676,7 +690,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
                 fgcolor: connectionData.fgcolor,
                 bgcolor: connectionData.bgcolor,
               },
-              connected: respData.data.trans_id ? true : false,
+              connected: Boolean(respData.data.trans_id),
               obtaining_conn: false,
             };
           });
@@ -699,7 +713,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
             });
           } else {
             selectConn(currSelectedConn, currConnected, false);
-            reject(error);
+            reject(error instanceof Error ? error : Error(gettext('Something went wrong')));
           }
         });
     });
@@ -736,12 +750,12 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
             );
           });
           if(existIdx > -1) {
-            reject(gettext('Connection with this configuration already present.'));
+            reject(new Error(gettext('Connection with this configuration already present.')));
             return;
           }
           updateQueryToolConnection(connectionData, true)
             .catch((err)=>{
-              reject(err);
+              reject(err instanceof Error ? err : Error(gettext('Something went wrong')));
             }).then(()=>{
               resolve();
               onClose();
@@ -785,7 +799,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
       id: 'manage-macros',
       title: gettext('Manage Macros'),
       content: <MacrosDialog onSave={(newMacros)=>{
-        setQtState((prev)=>{
+        setQtStatePartial((prev)=>{
           return {
             params: {
               ...prev.params,
@@ -798,6 +812,37 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
     }, 850, 500);
   }, [qtState.preferences.browser]);
 
+  const onAddToMacros = () => {
+    if (selectedText){
+      let currMacros = qtState.params.macros;
+      const existingNames = currMacros.map(macro => macro.name);
+      const newName = getRandomName(existingNames);
+      let changed = [{ 'name': newName, 'sql': selectedText }];
+
+      api.put(
+        url_for('sqleditor.set_macros', {
+          'trans_id': qtState.params.trans_id,
+        }),
+        { changed: changed }
+      )
+        .then(({ data: respData }) => {
+          const filteredData = respData.filter(m => Boolean(m.name));
+          setQtStatePartial(prev => ({
+            ...prev,
+            params: {
+              ...prev.params,
+              macros: filteredData,
+            },
+          }));
+        })
+        .catch(error => {
+          console.error(error);
+        });
+    }
+    setSelectedText('');
+  };
+
+
   const onFilterClick = useCallback(()=>{
     const onClose = ()=>docker.current.close('filter-dialog');
     docker.current.openDialog({
@@ -823,7 +868,8 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
     params: qtState.params,
     preferences: qtState.preferences,
     mainContainerRef: containerRef,
-    toggleQueryTool: () => setQtState((prev)=>{
+    editor_disabled: qtState.editor_disabled,
+    toggleQueryTool: () => setQtStatePartial((prev)=>{
       return {
         ...prev,
         params: {
@@ -834,7 +880,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
     }),
     updateTitle: (title) => {
       setPanelTitle(qtPanelDocker, qtPanelId, title, qtState, isDirtyRef.current);
-      setQtState((prev) => {
+      setQtStatePartial((prev) => {
         // Update connection Title
         let newConnList = [...prev.connection_list];
         newConnList.forEach((conn) => {
@@ -853,7 +899,7 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
         };
       });
     },
-  }), [qtState.params, qtState.preferences, containerRef.current]);
+  }), [qtState.params, qtState.preferences, containerRef.current, qtState.editor_disabled]);
 
   const queryToolConnContextValue = React.useMemo(()=>({
     connected: qtState.connected,
@@ -884,8 +930,9 @@ export default function QueryToolComponent({params, pgWindow, pgAdmin, selectedN
               <MainToolBar
                 containerRef={containerRef}
                 onManageMacros={onManageMacros}
+                onAddToMacros={onAddToMacros}
                 onFilterClick={onFilterClick}
-              />), [containerRef.current, onManageMacros, onFilterClick])}
+              />), [containerRef.current, onManageMacros, onFilterClick, onAddToMacros])}
             <Layout
               getLayoutInstance={(obj)=>docker.current=obj}
               defaultLayout={defaultLayout}
