@@ -26,6 +26,7 @@ export const QUERY_TOOL_EVENTS = {
   TRIGGER_REMOVE_FILTER: 'TRIGGER_REMOVE_FILTER',
   TRIGGER_SET_LIMIT: 'TRIGGER_SET_LIMIT',
   TRIGGER_FORMAT_SQL: 'TRIGGER_FORMAT_SQL',
+  TRIGGER_GRAPH_VISUALISER: 'TRIGGER_GRAPH_VISUALISER',
 
   COPY_DATA: 'COPY_DATA',
   SET_LIMIT_VALUE: 'SET_LIMIT_VALUE',
@@ -67,6 +68,7 @@ export const QUERY_TOOL_EVENTS = {
   WARN_SAVE_DATA_CLOSE: 'WARN_SAVE_DATA_CLOSE',
   WARN_SAVE_TEXT_CLOSE: 'WARN_SAVE_TEXT_CLOSE',
   WARN_TXN_CLOSE: 'WARN_TXN_CLOSE',
+  EXECUTE_CURSOR_WARNING: 'EXECUTE_CURSOR_WARNING',
 
   RESET_LAYOUT: 'RESET_LAYOUT',
   FORCE_CLOSE_PANEL: 'FORCE_CLOSE_PANEL',
