@@ -10,10 +10,15 @@
 """Implements pgAdmin4 User Management Utility"""
 
 import json
+
+import sys
+from unicodedata import normalize, is_normalized
+
 from flask import render_template, request, \
     Response, abort, current_app, session
 from flask_babel import gettext as _
-from flask_security import login_required, roles_required, current_user
+from flask_security import roles_required, current_user
+from pgadmin.user_login_check import pga_login_required
 from flask_security.utils import hash_password
 from werkzeug.exceptions import InternalServerError
 
@@ -73,13 +78,13 @@ blueprint = UserManagementModule(
 
 
 @blueprint.route("/")
-@login_required
+@pga_login_required
 def index():
     return bad_request(errormsg=_("This URL cannot be called directly."))
 
 
 @blueprint.route("/user_management.js")
-@login_required
+@pga_login_required
 def script():
     """render own javascript"""
     return Response(
@@ -95,7 +100,7 @@ def script():
 
 @blueprint.route("/current_user.js")
 @pgCSRFProtect.exempt
-@login_required
+@pga_login_required
 def current_user_info():
     return Response(
         response=render_template(
@@ -428,6 +433,22 @@ def save():
     )
 
 
+def normalise_password(password):
+    """
+    Normalise the password.
+    Flask security normalized the password prior to changing or comparing using
+    Python unicodedata.normalize(). As we are not using flask security form
+    to add/update user, we need custom function to do the same.
+    """
+    normalise_form = current_app.config.get(
+        'SECURITY_PASSWORD_NORMALIZE_FORM',
+        'NFKD'
+    )
+
+    return password if is_normalized(normalise_form, password) else\
+        normalize(normalise_form, password)
+
+
 def validate_password(data, new_data):
     """
     Check password new and confirm password match. If both passwords are not
@@ -439,7 +460,9 @@ def validate_password(data, new_data):
             'confirmPassword' in data and data['confirmPassword'] != ""):
 
         if data['newPassword'] == data['confirmPassword']:
-            new_data['password'] = hash_password(data['newPassword'])
+            new_data['password'] = hash_password(normalise_password(
+                data['newPassword'])
+            )
         else:
             raise InternalServerError(_("Passwords do not match."))
 
