@@ -9,14 +9,17 @@
 
 from email_validator import validate_email as email_validate, \
     EmailNotValidError
-import config
 
 
-def validate_email(email):
+def validate_email(email, check_email_deliverability=None):
     try:
+        if check_email_deliverability is None:
+            import config
+            check_email_deliverability = config.CHECK_EMAIL_DELIVERABILITY
+
         # Validate.
         _ = email_validate(
-            email, check_deliverability=config.CHECK_EMAIL_DELIVERABILITY)
+            email, check_deliverability=check_email_deliverability)
 
         # Update with the normalized form.
         return True
